@@ -35,6 +35,7 @@
 #include <stdlib.h>
 
 #include "cpe_name.h"
+#include "cpe_ctx_priv.h"
 
 #include "../common/public/oscap.h"
 #include "../common/util.h"
@@ -121,18 +122,18 @@ struct cpe_dict_model *cpe_dict_model_parse_xml(const char *file);
 
 /**
  * Parse generator part of CPE dictionary XML file
- * @param reader xmlTextReaderPtr representing XML model
+ * @param ctx CPE Parser's context
  * @return new structure cpe_generator
  */
-struct cpe_generator *cpe_generator_parse(xmlTextReaderPtr reader);
+struct cpe_generator *cpe_generator_parse(struct cpe_parser_ctx *ctx);
 
 /**
  * New dictionary item from XML
- * @param reader xmlTextReaderPtr representing XML model
+ * @param ctx CPE parser's context
  * @return new dictionary item
  * @retval NULL on failure
  */
-struct cpe_item *cpe_item_parse(xmlTextReaderPtr reader);
+struct cpe_item *cpe_item_parse(struct cpe_parser_ctx *ctx);
 
 /**
  * Parsing function to parse vendors of CPE dictionary
@@ -143,11 +144,11 @@ struct cpe_vendor *cpe_vendor_parse(xmlTextReaderPtr reader);
 
 /**
  * Load new CPE dictionary from XML node
- * @param reader xmlTextReaderPtr representing XML model
+ * @param ctx CPE parser context
  * @return new dictionary
  * @retval NULL on failure
  */
-struct cpe_dict_model *cpe_dict_model_parse(xmlTextReaderPtr reader);
+struct cpe_dict_model *cpe_dict_model_parse(struct cpe_parser_ctx *ctx);
 
 /**
  * Export function for CPE dictionary model
