@@ -33,13 +33,13 @@
 #include <libxml/xmlreader.h>
 #include <libxml/xmlwriter.h>
 
-#include "cpelang.h"
+#include "cpe_lang.h"
 #include "../common/util.h"
 #include "../common/list.h"
 #include "../common/elements.h"
 #include "../common/public/oscap.h"
 
-/** 
+/**
  * @cond INTERNAL
  */
 OSCAP_HIDDEN_START;
@@ -54,6 +54,11 @@ struct cpe_testexpr {
 	union {
 		struct oscap_list *expr;	///< array of subexpressions for operators
 		struct cpe_name *cpe;	///< CPE for match operation
+		struct {
+			char* system;
+			char* href;
+			char* id;
+		} check;
 	} meta;			///< operation metadata
 };
 
@@ -71,7 +76,7 @@ struct cpe_platform;
 
 /**
  * Function for parsing XML CPE language file
- * @param source structure of import source with filename and encoding
+ * @param file filename
  */
 struct cpe_lang_model *cpe_lang_model_parse_xml(const char *file);
 
@@ -97,8 +102,8 @@ struct cpe_testexpr *cpe_testexpr_parse(xmlTextReaderPtr reader);
 
 /**
  * Function for export CPE language model to XML
- * @param target structure with exporting information such filename and encoding
  * @param spec CPE language model structure
+ * @param file filename
  */
 void cpe_lang_model_export_xml(const struct cpe_lang_model *spec, const char *file);
 
