@@ -11,7 +11,7 @@
  */
 
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -31,11 +31,13 @@
  * Authors:
  *      Maros Barabas <mbarabas@redhat.com>
  *      Lukas Kuklinek <lkuklinek@redhat.com>
+ *      Šimon Lukašík
  */
 
 #ifndef CPEDICT_H_
 #define CPEDICT_H_
 
+#include "oscap.h"
 #include "cpe_name.h"
 #include "oscap_text.h"
 
@@ -175,11 +177,20 @@ const char *cpe_reference_get_content(const struct cpe_reference *item);
  */
 struct cpe_name *cpe_item_get_name(const struct cpe_item *item);
 
-/** cpe_item functions to get variable member deprecated
+/** cpe_item functions to get variable member deprecated_by
  * @memberof cpe_item
  * @param item CPE item
  */
-struct cpe_name *cpe_item_get_deprecated(const struct cpe_item *item);
+struct cpe_name *cpe_item_get_deprecated_by(const struct cpe_item *item);
+
+/** cpe_item functions to get variable member deprecated_by
+ * @memberof cpe_item
+ * @param item CPE item
+ * @returns deprecated_by attribute
+ * @deprecated This function has been deprecated by @ref cpe_item_get_deprecated_by.
+ * This function may be dropped from later versions of the library.
+ */
+OSCAP_DEPRECATED(struct cpe_name *cpe_item_get_deprecated(const struct cpe_item *item));
 
 /** cpe_item functions to get variable member date
  * @memberof cpe_item
@@ -214,8 +225,10 @@ struct oscap_text_iterator *cpe_item_get_titles(const struct cpe_item *item);
 /** cpe_item functions to get CPE notes
  * @memberof cpe_item
  * @param item CPE item
+ * @deprecated This function has been deprecated and it may be dropped from later
+ * versions of the library. (Please see upstream ticket #339 for further details).
  */
-struct oscap_text_iterator *cpe_item_get_notes(const struct cpe_item *item);
+OSCAP_DEPRECATED(struct oscap_text_iterator *cpe_item_get_notes(const struct cpe_item *item));
 
 /** cpe_generator functions to get product name
  * @memberof cpe_generator
@@ -500,8 +513,12 @@ bool cpe_item_add_check(struct cpe_item *item, struct cpe_check *new_check);
 /// @memberof cpe_item
 bool cpe_item_add_title(struct cpe_item *item, struct oscap_text *new_title);
 
-/// @memberof cpe_item
-bool cpe_item_add_note(struct cpe_item *item, struct oscap_text *new_title);
+/**
+ * @memberof cpe_item
+ * @deprecated This function has been deprecated and it may be dropped from later
+ * versions of the library. (Please see upstream ticket #339 for further details).
+ */
+OSCAP_DEPRECATED(bool cpe_item_add_note(struct cpe_item *item, struct oscap_text *new_title));
 
 /// @memberof cpe_dict_model
 bool cpe_dict_model_add_vendor(struct cpe_dict_model *dict, struct cpe_vendor *new_vendor);
