@@ -1,5 +1,5 @@
 /*
- * Copyright 2012 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2012--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -46,7 +46,7 @@
 
 static const char* arf_ns_uri = "http://scap.nist.gov/schema/asset-reporting-format/1.1";
 static const char* core_ns_uri = "http://scap.nist.gov/schema/reporting-core/1.1";
-static const char* arfvocab_ns_uri = "http://scap.nist.gov/vocabulary/arf/relationships/1.0#";
+static const char* arfvocab_ns_uri = "http://scap.nist.gov/specifications/arf/vocabulary/relationships/1.0#";
 static const char* ai_ns_uri = "http://scap.nist.gov/schema/asset-identification/1.1";
 
 static xmlNodePtr _lookup_container_in_arf(xmlDocPtr doc, const char *container_name)
@@ -692,14 +692,14 @@ int ds_rds_create(const char* sds_file, const char* xccdf_result_file, const cha
 	xmlDocPtr sds_doc = xmlReadFile(sds_file, NULL, 0);
 	if (!sds_doc)
 	{
-		oscap_seterr(OSCAP_EFAMILY_XML, "Failed to read source datastream from '%s'.\n", sds_file);
+		oscap_seterr(OSCAP_EFAMILY_XML, "Failed to read source datastream from '%s'.", sds_file);
 		return -1;
 	}
 
 	xmlDocPtr result_file_doc = xmlReadFile(xccdf_result_file, NULL, 0);
 	if (!result_file_doc)
 	{
-		oscap_seterr(OSCAP_EFAMILY_XML, "Failed to read XCCDF result file document from '%s'.\n", xccdf_result_file);
+		oscap_seterr(OSCAP_EFAMILY_XML, "Failed to read XCCDF result file document from '%s'.", xccdf_result_file);
 		xmlFreeDoc(sds_doc);
 		return -1;
 	}
@@ -718,7 +718,7 @@ int ds_rds_create(const char* sds_file, const char* xccdf_result_file, const cha
 			oval_result_docs[oval_result_docs_count] = xmlReadFile(*oval_result_files, NULL, 0);
 			if (!oval_result_docs[oval_result_docs_count])
 			{
-				oscap_seterr(OSCAP_EFAMILY_XML, "Failed to read OVAL result file document from '%s'.\n", *oval_result_files);
+				oscap_seterr(OSCAP_EFAMILY_XML, "Failed to read OVAL result file document from '%s'.", *oval_result_files);
 				result = -1;
 				continue;
 			}
@@ -737,7 +737,7 @@ int ds_rds_create(const char* sds_file, const char* xccdf_result_file, const cha
 	// we won't even try to save the file if error happened when creating the DOM
 	if (result == 0 && xmlSaveFileEnc(target_file, rds_doc, "utf-8") == -1)
 	{
-		oscap_seterr(OSCAP_EFAMILY_XML, "Failed to save the result datastream to '%s'.\n", target_file);
+		oscap_seterr(OSCAP_EFAMILY_XML, "Failed to save the result datastream to '%s'.", target_file);
 		result = -1;
 	}
 	xmlFreeDoc(rds_doc);
