@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009-2010 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -40,10 +40,10 @@
 #include "oval_definitions_impl.h"
 #include "oval_agent_api_impl.h"
 #include "oval_parser_impl.h"
-#include "oval_string_map_impl.h"
+#include "adt/oval_string_map_impl.h"
 #include "oval_system_characteristics_impl.h"
 #include "oval_probe_impl.h"
-#include "oval_results_impl.h"
+#include "results/oval_results_impl.h"
 #include "common/list.h"
 #include "common/util.h"
 #include "common/debug_priv.h"
@@ -139,10 +139,21 @@ void oval_agent_set_product_name(oval_agent_session_t *ag_sess, char * product_n
 	oval_generator_set_product_name(generator, product_name);
 }
 
+static struct oval_result_system *_oval_agent_get_first_result_system(oval_agent_session_t *ag_sess)
+{
+	struct oval_results_model *rmodel = oval_agent_get_results_model(ag_sess);
+	struct oval_result_system_iterator *rsystem_it = oval_results_model_get_systems(rmodel);
+	struct oval_result_system *rsystem = NULL;
+	if (oval_result_system_iterator_has_more(rsystem_it)) {
+		rsystem = oval_result_system_iterator_next(rsystem_it);
+	}
+	oval_result_system_iterator_free(rsystem_it);
+	return rsystem;
+}
+
 int oval_agent_eval_definition(oval_agent_session_t *ag_sess, const char *id)
 {
 	int ret;
-	struct oval_result_system_iterator *rsystem_it;
 	struct oval_result_system *rsystem;
 
 	/* probe */
@@ -150,10 +161,7 @@ int oval_agent_eval_definition(oval_agent_session_t *ag_sess, const char *id)
 	if (ret == -1)
 		return ret;
 
-	/* take the first system */
-	rsystem_it = oval_results_model_get_systems(ag_sess->res_model);
-	rsystem = oval_result_system_iterator_next(rsystem_it);
-        oval_result_system_iterator_free(rsystem_it);
+	rsystem = _oval_agent_get_first_result_system(ag_sess);
 	/* eval */
 	ret = oval_result_system_eval_definition(rsystem, id);
 
@@ -162,21 +170,15 @@ int oval_agent_eval_definition(oval_agent_session_t *ag_sess, const char *id)
 
 int oval_agent_get_definition_result(oval_agent_session_t *ag_sess, const char *id, oval_result_t * result)
 {
-	struct oval_results_model *rmodel;
-	struct oval_result_system_iterator *rsystem_it;
 	struct oval_result_system *rsystem;
 	struct oval_result_definition *rdef;
 
-	rmodel = oval_agent_get_results_model(ag_sess);
-	rsystem_it = oval_results_model_get_systems(rmodel);
-	if (!oval_result_system_iterator_has_more(rsystem_it)) {
-		oval_result_system_iterator_free(rsystem_it);
+	rsystem = _oval_agent_get_first_result_system(ag_sess);
+	if (rsystem == NULL) {
 		oscap_seterr(OSCAP_EFAMILY_OSCAP, "No results system in agent session.");
                 return -1;
 	}
 
-	rsystem = oval_result_system_iterator_next(rsystem_it);
-	oval_result_system_iterator_free(rsystem_it);
 	rdef = oval_result_system_get_definition(rsystem, id);
         if (rdef == NULL) {
                 oscap_seterr(OSCAP_EFAMILY_OSCAP, "No definition with ID: %s in result model.", id);
@@ -189,20 +191,13 @@ int oval_agent_get_definition_result(oval_agent_session_t *ag_sess, const char *
 }
 
 struct oval_result_definition * oval_agent_get_result_definition(oval_agent_session_t *ag_sess, const char *id) {
-	struct oval_results_model *rmodel;
-	struct oval_result_system_iterator *rsystem_it;
 	struct oval_result_system *rsystem;
 	struct oval_result_definition *rdef;
 
-	rmodel = oval_agent_get_results_model(ag_sess);
-	rsystem_it = oval_results_model_get_systems(rmodel);
-	if (!oval_result_system_iterator_has_more(rsystem_it)) {
-		oval_result_system_iterator_free(rsystem_it);
-                return NULL;
-	}
+	rsystem = _oval_agent_get_first_result_system(ag_sess);
+	if (rsystem == NULL)
+		return NULL;
 
-	rsystem = oval_result_system_iterator_next(rsystem_it);
-	oval_result_system_iterator_free(rsystem_it);
 	rdef = oval_result_system_get_definition(rsystem, id);
 
 	return rdef;
@@ -212,12 +207,16 @@ int oval_agent_reset_session(oval_agent_session_t * ag_sess) {
 	ag_sess->cur_var_model = NULL;
 	oval_definition_model_clear_external_variables(ag_sess->def_model);
 
-	/* Reset syschar model */
-	oval_syschar_model_reset(ag_sess->sys_model);
+	/* We intentionally do not flush out the results model which should
+	 * be able to encompass results from multiple evaluations */
 
-	/* Replace result model */
-	oval_results_model_free(ag_sess->res_model);
-	ag_sess->res_model = oval_results_model_new(ag_sess->def_model, ag_sess->sys_models);
+	/* Here we temporarily do not flush out the system characteristics model
+	 * because there might be tests in the results model which refer to this
+	 * sys char (via @tested_item attribute). Later we will need a mechanism
+	 * to selectivelly invalidate some of the system characteristics cached
+	 * objects (similar to the concept of variable_instance_hint from the
+	 * results model. Hooray corner cases! */
+	//oval_syschar_model_reset(ag_sess->sys_model);
 
 	/* Apply product name to new results_model */
 	if (ag_sess->product_name) {
@@ -389,8 +388,58 @@ static void _oval_agent_resolve_variables_conflict(struct oval_agent_session *se
 		struct oval_variable *variable = oval_definition_model_get_variable(def_model, var_name);
 		if (variable != NULL) {
 			struct oval_value_iterator *value_it = oval_variable_get_values(variable);
-			if (_stringlist_conflicts_with_value_it(value_list, value_it))
+			if (_stringlist_conflicts_with_value_it(value_list, value_it)) {
+				// You don't want to touch this code. There are also other means to waste your
+				// life. Now please proceed by reading the previous line again.
+				//
+				// Now, we have found that the variable we are trying to bind into the session
+				// is already there with different values. This is the rise of concept which
+				// is often referred as variable_instance or simply multiset.
+				//
+				// As per OVAL 5.10.1, the Variable Schema does not allow multisets. Therefore,
+				// we will later create new variable model and export multiple variables docs.
 				conflict = true;
+				// Next, in the results model, there might be already some definitions, tests
+				// states, or objects. These might be dependent on the previous value of the
+				// given variable.
+				//
+				// The 'latest' result-definition for each such definition (whose result depends
+				// on the value) needs to be marked by 'variable_instance_hint'. The hint has
+				// meaning that any possible future evaluation of the given definition needs
+				// to create new result-definition and not re-use the old one.
+				//
+				// Both (or all) such result-definitions are then distinguished by different
+				// @variable_instance attribute. And each result-definition refers to different
+				// set of tests. These tests might have same @id but differ in @variable_instance
+				// attribute. Further, some of these tests will differ in tested_variable element.
+				struct oval_result_system *r_system = _oval_agent_get_first_result_system(session);
+				if (r_system == NULL)
+					continue;
+
+				struct oval_string_iterator *def_it =
+					oval_definition_model_get_definitions_dependent_on_variable(def_model, variable);
+				while (oval_string_iterator_has_more(def_it)) {
+					char *definition_id = oval_string_iterator_next(def_it);
+
+					struct oval_result_definition *r_definition = oval_result_system_get_definition(r_system, definition_id);
+					if (r_definition != NULL) {
+						// Here we simply increase the variable_instance_hint, however
+						// in future we might want to do better and have a single session wide
+						// counter and set the variable_instance_hints to this given counter.
+						// That would allow the one-to-one mapping of variable_instance attributes
+						// to the oval_variable files.
+						int instance = oval_result_definition_get_instance(r_definition);
+						oval_result_definition_set_variable_instance_hint(r_definition, instance + 1);
+						struct oval_definition *definition = oval_result_definition_get_definition(r_definition);
+						oval_probe_hint_definition(session->psess, definition, instance + 1);
+					}
+					else {
+						// TODO: We really need oval_agent_session wide variable_instance attribute
+						// to be able to correctly handle syschars even when there is no result-definition.
+					}
+				}
+				oval_string_iterator_free(def_it);
+			}
 			oval_value_iterator_free(value_it);
 		}
 	}
