@@ -32,6 +32,7 @@
 
 #include <libxml/xmlreader.h>
 #include "public/oval_definitions.h"
+#include "public/oval_system_characteristics.h"
 #include "oval_parser_impl.h"
 #include "adt/oval_string_map_impl.h"
 #include "../common/util.h"
@@ -86,6 +87,7 @@ struct oval_object *oval_object_clone2(struct oval_definition_model *, struct ov
 struct oval_object *oval_object_create_internal(struct oval_object *, char *);
 struct oval_object *oval_object_get_base_obj(struct oval_object *);
 
+oval_version_t oval_state_get_schema_version(const struct oval_state *state);
 int oval_state_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context *context, void *);
 xmlNode *oval_state_to_dom(struct oval_state *, xmlDoc *, xmlNode *);
 
@@ -120,7 +122,7 @@ xmlNode *oval_entity_to_dom(struct oval_entity *, xmlDoc *, xmlNode *);
 
 int oval_record_field_parse_tag(xmlTextReaderPtr, struct oval_parser_context *,
 				oscap_consumer_func, void *, oval_record_field_type_t);
-xmlNode *oval_record_field_to_dom(struct oval_record_field *, bool, xmlDoc *, xmlNode *);
+xmlNode *oval_record_field_to_dom(struct oval_record_field *, bool, xmlDoc *, xmlNode *, xmlNs *);
 
 typedef void (*oval_set_consumer) (struct oval_setobject *, void *);
 int oval_set_parse_tag(xmlTextReaderPtr, struct oval_parser_context *, oval_set_consumer, void *);
