@@ -35,6 +35,8 @@
 #include <stdio.h>
 #include <string.h>
 
+#include <libxml/tree.h>
+
 #include "oval_definitions_impl.h"
 #include "adt/oval_collection_impl.h"
 #include "oval_agent_api_impl.h"
@@ -58,6 +60,7 @@ struct oval_entity {
 	char *name;
 	struct oval_variable *variable;
 	struct oval_value *value;
+	bool xsi_nil;				///< @xsi:nil boolean attribute
 };
 
 struct oval_consume_varref_context {
@@ -69,6 +72,9 @@ struct oval_consume_varref_context {
 /* End of variable definitions
  * */
 /***************************************************************************/
+static inline bool oval_entity_get_xsi_nil(const struct oval_entity *entity);
+static inline void oval_entity_set_xsi_nil(struct oval_entity *entity, bool xsi_nil);
+
 
 bool oval_entity_iterator_has_more(struct oval_entity_iterator *oc_entity)
 {
@@ -124,6 +130,12 @@ int oval_entity_get_mask(struct oval_entity *entity)
 	return entity->mask;
 }
 
+static inline bool oval_entity_get_xsi_nil(const struct oval_entity *entity)
+{
+	__attribute__nonnull__(entity);
+	return entity->xsi_nil;
+}
+
 oval_entity_varref_type_t oval_entity_get_varref_type(struct oval_entity * entity)
 {
 	__attribute__nonnull__(entity);
@@ -153,6 +165,7 @@ struct oval_entity *oval_entity_new(struct oval_definition_model *model)
 
 	entity->datatype = OVAL_DATATYPE_UNKNOWN;
 	entity->mask = 0;
+	entity->xsi_nil = 0;
 	entity->operation = OVAL_OPERATION_UNKNOWN;
 	entity->type = OVAL_ENTITY_TYPE_UNKNOWN;
 	entity->name = NULL;
@@ -168,6 +181,8 @@ struct oval_entity *oval_entity_clone(struct oval_definition_model *new_model, s
 	oval_entity_set_datatype(new_entity, datatype);
 	int mask = oval_entity_get_mask(old_entity);
 	oval_entity_set_mask(new_entity, mask);
+	bool xsi_nil = oval_entity_get_xsi_nil(old_entity);
+	oval_entity_set_xsi_nil(new_entity, xsi_nil);
 	char *name = oval_entity_get_name(old_entity);
 	oval_entity_set_name(new_entity, name);
 	oval_operation_t operation = oval_entity_get_operation(old_entity);
@@ -226,6 +241,12 @@ void oval_entity_set_mask(struct oval_entity *entity, int mask)
 	entity->mask = mask;
 }
 
+static inline void oval_entity_set_xsi_nil(struct oval_entity *entity, bool xsi_nil)
+{
+	__attribute__nonnull__(entity);
+	entity->xsi_nil = xsi_nil;
+}
+
 void oval_entity_set_varref_type(struct oval_entity *entity, oval_entity_varref_type_t type)
 {
 	__attribute__nonnull__(entity);
@@ -279,6 +300,11 @@ int oval_entity_parse_tag(xmlTextReaderPtr reader,
 	oval_datatype_t datatype = oval_datatype_parse(reader, "datatype", OVAL_DATATYPE_STRING);
 	oval_operation_t operation = oval_operation_parse(reader, "operation", OVAL_OPERATION_EQUALS);
 	int mask = oval_parser_boolean_attribute(reader, "mask", 0);
+
+	char *nil_attr = (char *) xmlTextReaderGetAttributeNs(reader, BAD_CAST "nil", OVAL_XMLNS_XSI);
+	int xsi_nil = oscap_streq(nil_attr, "true") != 0;
+	xmlFree(nil_attr);
+
 	oval_entity_type_t type = OVAL_ENTITY_TYPE_UNKNOWN;
 	//The value of the type field vs. the complexity of extracting type is arguable
 	char *varref = (char *)xmlTextReaderGetAttribute(reader, BAD_CAST "var_ref");
@@ -306,7 +332,7 @@ int oval_entity_parse_tag(xmlTextReaderPtr reader,
 		if (datatype == OVAL_DATATYPE_RECORD) {
 			value = NULL;
 		} else {
-			if (oval_parser_boolean_attribute(reader, "xsi:nil", 0))
+			if (xsi_nil)
 				value = NULL;
 			else
 				return_code = oval_value_parse_tag(reader, context, &oval_consume_value, &value);
@@ -327,6 +353,7 @@ int oval_entity_parse_tag(xmlTextReaderPtr reader,
 	oval_entity_set_varref_type(entity, varref_type);
 	oval_entity_set_variable(entity, variable);
 	oval_entity_set_value(entity, value);
+	oval_entity_set_xsi_nil(entity, xsi_nil);
 	(*consumer) (entity, user);
 
 	if (return_code != 0) {
@@ -366,6 +393,18 @@ xmlNode *oval_entity_to_dom(struct oval_entity *entity, xmlDoc * doc, xmlNode *
 		oval_operation_t operation = oval_entity_get_operation(entity);
 		if (operation != OVAL_OPERATION_EQUALS)
 			xmlNewProp(entity_node, BAD_CAST "operation", BAD_CAST oval_operation_get_text(operation));
+		if (oscap_streq(content, "") && oval_entity_get_xsi_nil(entity)) {
+			// Look-up xsi namespace pointer. We can be pretty sure that this namespace
+			// is defined in root element, because it usually carries xsi:schemaLocation
+			// attribute.
+			xmlNsPtr ns_xsi = xmlSearchNsByHref(doc, xmlDocGetRootElement(doc), OVAL_XMLNS_XSI);
+			if (ns_xsi == NULL) {
+				assert(ns_xsi != NULL); // Spot this in testing
+				ns_xsi = xmlNewNs(xmlDocGetRootElement(doc), OVAL_XMLNS_XSI, BAD_CAST "xsi");
+			}
+			// Export @xsi:nil="true" only if it was imported and the content is still empty
+			xmlNewNsProp(entity_node, ns_xsi, BAD_CAST "nil", BAD_CAST "true");
+		}
 	}
 
 	oval_datatype_t datatype = oval_entity_get_datatype(entity);
