@@ -37,8 +37,9 @@
 #include "oval_definitions_impl.h"
 #include "adt/oval_string_map_impl.h"
 #include "oval_system_characteristics_impl.h"
-#include "oval_results_impl.h"
+#include "results/oval_results_impl.h"
 #include "common/util.h"
+#include "common/_error.h"
 #include "common/debug_priv.h"
 
 const char _invalid[] = "**INVALID**";
@@ -368,6 +369,10 @@ static const struct oscap_string_map OVAL_FAMILY_MAP[] = {
 oval_family_t oval_family_parse(xmlTextReaderPtr reader)
 {
 	char *namespace = (char *)xmlTextReaderNamespaceUri(reader);
+	if (namespace == NULL) {
+		oscap_seterr(OSCAP_EFAMILY_XML, "Could not find namespace definition for prefix '%s'", (char *) xmlTextReaderConstPrefix(reader));
+		return OVAL_FAMILY_UNKNOWN;
+	}
 	char *family_text = strrchr(namespace, '#');
 	if (family_text == NULL) {
 		dW("No OVAL family for namespace: %s\n", namespace);
@@ -626,10 +631,14 @@ oval_subtype_t oval_subtype_parse(xmlTextReaderPtr reader)
 		goto cleanup;
 	}
 
-	subtype = oscap_string_to_enum(map, tagname);
-
-	if (subtype == OVAL_ENUMERATION_INVALID)
+	int subtype_s = oscap_string_to_enum(map, tagname);
+	if (subtype < 0) {
 		dW("Unknown OVAL family subtype: %s\n", tagname);
+		subtype = OVAL_ENUMERATION_INVALID;
+	}
+	else {
+		subtype = subtype_s;
+	}
 
  cleanup:
 	oscap_free(tagname);
@@ -694,7 +703,7 @@ const char *oval_subtype_get_text(oval_subtype_t subtype)
 	if (map) {
 		return oval_enumeration_get_text(map, subtype);
 	} else {
-		fprintf(stderr, "WARNING: ZERO FAMILY INDEX\n    %s(%d)\n", __FILE__, __LINE__);
+		oscap_seterr(OSCAP_EFAMILY_OSCAP, "Warning: Zero family index");
 		return _invalid;
 	}
 }
