@@ -45,11 +45,6 @@
 #include "common/elements.h"
 #include "common/public/oscap.h"
 
-void libxml_error_handler(void *user, const char *message, xmlParserSeverities severity, xmlTextReaderLocatorPtr locator)
-{
-	oscap_setxmlerr(xmlGetLastError());
-}
-
 /**
  * -1 error; 0 OK; 1 warning
  */
@@ -86,6 +81,8 @@ char *oval_determine_document_schema_version(const char *document, oscap_documen
 		return NULL;
 	}
 
+	xmlTextReaderSetErrorHandler(reader, &libxml_error_handler, NULL);
+
 	/* find root element */
 	while (xmlTextReaderRead(reader) == 1
 	       && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT);
@@ -146,7 +143,7 @@ char *oval_determine_document_schema_version(const char *document, oscap_documen
 	}
 
 	xmlFreeTextReader(reader);
-	char* ret = strdup((const char*)version);
+	char* ret = oscap_strdup((const char*)version);
 	xmlFree(version);
 
 	return ret;
