@@ -7,7 +7,7 @@
  * @{
  */
 /*
- * Copyright 2009-2010 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -36,7 +36,6 @@
 #include "oval_definitions_impl.h"
 #include "oval_agent_api_impl.h"
 #include "oval_parser_impl.h"
-#include "oval_string_map_impl.h"
 #include "public/oval_system_characteristics.h"
 #include "../common/util.h"
 #include "public/oval_probe.h"
@@ -69,5 +68,7 @@ void oval_probe_tblinit(void);
 const char *oval_subtype_to_str(oval_subtype_t subtype);
 oval_subtype_t oval_str_to_subtype(const char *str);
 
+int oval_probe_hint_definition(oval_probe_session_t *sess, struct oval_definition *definition, int variable_instance_hint);
+
 #endif /* OVAL_PROBE_IMPL_H */
 /// @}
