@@ -178,7 +178,7 @@ struct oval_state *oval_state_clone(struct oval_definition_model *new_model, str
 		struct oval_string_iterator *notes = oval_state_get_notes(old_state);
 		while (oval_string_iterator_has_more(notes)) {
 			char *note = oval_string_iterator_next(notes);
-			oval_state_add_note(new_state, strdup(note));
+			oval_state_add_note(new_state, note);
 		}
 		oval_string_iterator_free(notes);
 		struct oval_state_content_iterator *contents = oval_state_get_contents(old_state);
@@ -253,6 +253,18 @@ void oval_state_add_content(struct oval_state *state, struct oval_state_content
 	oval_collection_add(state->contents, content);
 }
 
+oval_version_t oval_state_get_schema_version(const struct oval_state *state)
+{
+	__attribute__nonnull__(state);
+
+	if (state->model == NULL)
+		return OVAL_VERSION_INVALID;
+
+	struct oval_generator *gen = oval_definition_model_get_generator(state->model);
+	const char *ver_str = oval_generator_get_schema_version(gen);
+	return oval_version_from_cstr(ver_str);
+}
+
 static void _oval_note_consumer(char *text, void *state)
 {
 	oval_state_add_note(state, text);
