@@ -305,11 +305,18 @@ void oval_sysent_to_dom(struct oval_sysent *sysent, xmlDoc * doc, xmlNode * pare
 	}
 
 	rf_itr = oval_sysent_get_record_fields(sysent);
-	while (oval_record_field_iterator_has_more(rf_itr)) {
-		struct oval_record_field *rf;
+	if (oval_record_field_iterator_has_more(rf_itr)) {
+		xmlNsPtr field_ns = xmlSearchNsByHref(doc, xmlDocGetRootElement(doc), OVAL_SYSCHAR_NAMESPACE);
+		if (field_ns == NULL) {
+			field_ns = xmlNewNs(xmlDocGetRootElement(doc), OVAL_SYSCHAR_NAMESPACE, NULL);
+		}
 
-		rf = oval_record_field_iterator_next(rf_itr);
-		oval_record_field_to_dom(rf, mask, doc, sysent_tag);
+		while (oval_record_field_iterator_has_more(rf_itr)) {
+			struct oval_record_field *rf;
+
+			rf = oval_record_field_iterator_next(rf_itr);
+			oval_record_field_to_dom(rf, mask, doc, sysent_tag, field_ns);
+		}
 	}
 	oval_record_field_iterator_free(rf_itr);
 }
