@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -37,7 +37,8 @@
 
 #include "oval_agent_api_impl.h"
 #include "oval_system_characteristics_impl.h"
-#include "oval_collection_impl.h"
+#include "adt/oval_collection_impl.h"
+#include "oval_definitions_impl.h"
 #include "common/util.h"
 #include "common/debug_priv.h"
 
@@ -49,7 +50,7 @@ typedef struct oval_sysitem {
 	struct oval_collection *messages;
 	struct oval_collection *sysents;
 	oval_syschar_status_t status;
-} oval_sysitem_t;
+} oval_sysitem_t;				///< Represents a single <*_item> element
 
 struct oval_sysitem *oval_sysitem_new(struct oval_syschar_model *model, const char *id)
 {
