@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -25,6 +25,7 @@
  *
  * Authors:
  *      "David Niemoller" <David.Niemoller@g2-inc.com>
+ *      Šimon Lukašík
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,8 +37,9 @@
 #include <string.h>
 
 #include "oval_system_characteristics_impl.h"
-#include "oval_collection_impl.h"
+#include "adt/oval_collection_impl.h"
 #include "oval_agent_api_impl.h"
+#include "oval_definitions_impl.h"
 
 #include "common/assume.h"
 #include "common/util.h"
@@ -48,28 +50,11 @@ typedef struct oval_syschar {
 	oval_syschar_collection_flag_t flag;
 	struct oval_collection *messages;
 	struct oval_object *object;
-	struct oval_collection *variable_bindings;
-	struct oval_collection *sysitem;
-} oval_syschar_t;
-
-bool oval_syschar_iterator_has_more(struct oval_syschar_iterator *oc_syschar)
-{
-	return oval_collection_iterator_has_more((struct oval_iterator *)
-						 oc_syschar);
-}
-
-struct oval_syschar *oval_syschar_iterator_next(struct oval_syschar_iterator
-						*oc_syschar)
-{
-	return (struct oval_syschar *)
-	    oval_collection_iterator_next((struct oval_iterator *)oc_syschar);
-}
-
-void oval_syschar_iterator_free(struct oval_syschar_iterator
-				*oc_syschar)
-{
-	oval_collection_iterator_free((struct oval_iterator *)oc_syschar);
-}
+	struct oval_collection *variable_bindings;	///< Represents <variable_value> elements
+	struct oval_collection *sysitem;		///< Represents <reference> elements
+	int variable_instance;				///< Represents variable_instance attribute
+	int variable_instance_hint;			///< Internal hint of the next possible variable_instance attribute
+} oval_syschar_t;					///< Represents a single collected <object> element
 
 oval_syschar_collection_flag_t oval_syschar_get_flag(struct oval_syschar
 						     *syschar)
@@ -166,6 +151,8 @@ struct oval_syschar *oval_syschar_new(struct oval_syschar_model *model, struct o
 		return NULL;
 
 	syschar->flag = SYSCHAR_FLAG_UNKNOWN;
+	syschar->variable_instance = 1;
+	syschar->variable_instance_hint = 1;
 	syschar->object = object;
 	syschar->messages = oval_collection_new();
 	syschar->sysitem = oval_collection_new();
@@ -190,6 +177,9 @@ struct oval_syschar *oval_syschar_clone(struct oval_syschar_model *new_model, st
 
 	oval_syschar_collection_flag_t flag = oval_syschar_get_flag(old_syschar);
 	oval_syschar_set_flag(new_syschar, flag);
+	int variable_instance = oval_syschar_get_variable_instance(old_syschar);
+	oval_syschar_set_variable_instance(new_syschar, variable_instance);
+	oval_syschar_set_variable_instance_hint(new_syschar, variable_instance);
 
 	struct oval_message_iterator *old_messages = oval_syschar_get_messages(old_syschar);
 	while (oval_message_iterator_has_more(old_messages)) {
@@ -346,6 +336,14 @@ void oval_syschar_to_dom(struct oval_syschar *syschar, xmlDoc * doc, xmlNode * t
 			xmlNewProp(tag_syschar, BAD_CAST "version", BAD_CAST version);
 			oval_syschar_collection_flag_t flag = oval_syschar_get_flag(syschar);
 			xmlNewProp(tag_syschar, BAD_CAST "flag", BAD_CAST oval_syschar_collection_flag_get_text(flag));
+
+			int instance = oval_syschar_get_variable_instance(syschar);
+			if (instance != 1 ||
+				oval_syschar_get_variable_instance_hint(syschar) != instance) {
+				char instance_att[10] = "";
+				snprintf(instance_att, sizeof(instance_att), "%d", instance);
+				xmlNewProp(tag_syschar, BAD_CAST "variable_instance", BAD_CAST instance_att);
+			}
 		}
 		{		/*messages */
 			struct oval_message_iterator *messages = oval_syschar_get_messages(syschar);
@@ -375,3 +373,34 @@ void oval_syschar_to_dom(struct oval_syschar *syschar, xmlDoc * doc, xmlNode * t
 		}
 	}
 }
+
+int oval_syschar_get_variable_instance(const struct oval_syschar *syschar)
+{
+	__attribute__nonnull__(syschar);
+	return syschar->variable_instance;
+}
+
+void oval_syschar_set_variable_instance(struct oval_syschar *syschar, int variable_instance_in)
+{
+	__attribute__nonnull__(syschar);
+	syschar->variable_instance = variable_instance_in;
+}
+
+int oval_syschar_get_variable_instance_hint(const struct oval_syschar *syschar)
+{
+	__attribute__nonnull__(syschar);
+	return syschar->variable_instance_hint;
+}
+
+void oval_syschar_set_variable_instance_hint(struct oval_syschar *syschar, int variable_instance_hint_in)
+{
+	__attribute__nonnull__(syschar);
+	syschar->variable_instance_hint = variable_instance_hint_in;
+}
+
+const char *oval_syschar_get_id(const struct oval_syschar *syschar)
+{
+	__attribute__nonnull__(syschar);
+	struct oval_object *obj = oval_syschar_get_object((struct oval_syschar *) syschar);
+	return (obj == NULL) ? NULL : oval_object_get_id(obj);
+}
