@@ -32,7 +32,8 @@
 #define OVAL_SYSCHAR_IMPL
 
 #include "public/oval_system_characteristics.h"
-#include "oval_definitions_impl.h"
+#include "oval_parser_impl.h"
+#include "adt/oval_smc_impl.h"
 #include "../common/util.h"
 
 OSCAP_HIDDEN_START;
@@ -76,6 +77,11 @@ void oval_syschar_model_add_sysitem(struct oval_syschar_model *model, struct ova
 void oval_syschar_model_set_schema(struct oval_syschar_model *model, const char * schema);
 const char * oval_syschar_model_get_schema(struct oval_syschar_model * model);
 
+struct oval_syschar_iterator *oval_syschar_iterator_new(struct oval_smc *mapping);
+int oval_syschar_get_variable_instance_hint(const struct oval_syschar *syschar);
+void oval_syschar_set_variable_instance_hint(struct oval_syschar *syschar, int variable_instance_hint_in);
+const char *oval_syschar_get_id(const struct oval_syschar *syschar);
+
 OSCAP_HIDDEN_END;
 
 #endif
