@@ -366,7 +366,7 @@ struct oval_variable *oval_variable_new(struct oval_definition_model *model, con
 		};
 		break;
 	default:
-		oscap_seterr(OSCAP_EFAMILY_OVAL, "Variable type is not valid: %d.\n", type);
+		oscap_seterr(OSCAP_EFAMILY_OVAL, "Variable type is not valid: %d.", type);
 		return NULL;
 	}
 
