@@ -24,8 +24,13 @@
  * Sparse buffer API implementation
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 #include <errno.h>
+
 #include "spb.h"
 #include "sm_alloc.h"
 
