@@ -30,8 +30,19 @@
 extern "C" {
 #endif
 
+struct SEAP_err {
+        SEAP_msgid_t id;
+        uint32_t     code;
+        uint8_t      type;
+        SEXP_t      *data;
+};
+
 typedef struct SEAP_err SEAP_err_t;
 
+SEAP_err_t *SEAP_error_new(void);
+SEAP_err_t *SEAP_error_clone(SEAP_err_t *e);
+void SEAP_error_free(SEAP_err_t *e);
+
 #ifdef __cplusplus
 }
 #endif
