@@ -20,8 +20,13 @@
  *      "Daniel Kopecek" <dkopecek@redhat.com>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stddef.h>
 #include <string.h>
+
 #include "generic/common.h"
 #include "_seap-scheme.h"
 
