@@ -25,6 +25,7 @@
 //#endif
 
 #include <stdint.h>
+#include <string.h>
 
 #include "_sexp-atomic.h"
 #include "_sexp-value.h"
@@ -47,7 +48,7 @@ int SEXP_val_new (SEXP_val_t *dst, size_t vmemsize, SEXP_type_t type)
         dst->type      = type;
         dst->ptr       = SEXP_val_ptr (dst);
 #if defined(SEAP_VERBOSE_DEBUG)
-        _D("\n"
+        dI("\n"
            "new value: hdr->refs = %u\n"
            "           hdr->size = %zu\n"
            "                type = %hhu\n"
@@ -305,8 +306,6 @@ SEXP_t *SEXP_rawval_lblk_nth (uintptr_t lblkp, uint32_t n)
 {
         register struct SEXP_val_lblk *lblk;
 
-        _LOGCALL_;
-
         lblk = SEXP_VALP_LBLK(lblkp);
 
         while (lblk != NULL) {
@@ -560,3 +559,22 @@ void SEXP_rawval_lblk_free1 (uintptr_t lblkp, void (*func) (SEXP_t *))
 
         return;
 }
+
+uintptr_t SEXP_rawval_copy(uintptr_t s_valp)
+{
+	uintptr_t uptr;
+	SEXP_val_t v_dsc;
+	SEXP_val_dsc(&v_dsc, s_valp);
+
+	if (v_dsc.type != SEXP_VALTYPE_LIST) {
+		SEXP_val_t v_dsc_copy;
+		if (SEXP_val_new(&v_dsc_copy, v_dsc.hdr->size, v_dsc.type) != 0) {
+			return ((uintptr_t)NULL);
+		}
+		memcpy(v_dsc_copy.mem, v_dsc.mem, v_dsc.hdr->size);
+		uptr = SEXP_val_ptr(&v_dsc_copy);
+	} else {
+		uptr = SEXP_rawval_list_copy(s_valp);
+	}
+	return uptr;
+}
