@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -91,11 +91,11 @@ dbEngineMap_t engine_map[] = {
 
 #define ENGINE_MAP_COUNT (sizeof engine_map / sizeof (dbEngineMap_t))
 
-static int engine_cmp (const dbEngineMap_t *a, const dbEngineMap_t *b)
+static int engine_cmp (const char *a, const dbEngineMap_t *b)
 {
 	assume_d(a != NULL, -1);
 	assume_d(b != NULL, -1);
-	return strcmp(a->o_engine, b->o_engine);
+	return strcmp(a, b->o_engine);
 }
 
 typedef struct {
@@ -175,8 +175,9 @@ static void dbURIInfo_clear(dbURIInfo_t *ui)
 
 static int dbURIInfo_parse(dbURIInfo_t *info, const char *conn)
 {
-	char *tmp, *tok, *copy = strdup(conn);
-
+	char *tmp, *tok, *copy;
+	char *conn_copy = strdup(conn);
+	copy = conn_copy;
 	if (copy == NULL)
 		return (-1);
 
@@ -184,33 +185,36 @@ static int dbURIInfo_parse(dbURIInfo_t *info, const char *conn)
 
 #define matchitem1(tok, first, rest, dst)			\
 	case first:						\
-		if (strcasecmp((rest), ++(tok)) == 0) {		\
+		if (strncasecmp((rest), ++(tok), strlen(rest)) == 0) {	\
 			tok += strlen(rest);			\
 			skipspace(tok);				\
 			if (*(tok) != '=') goto __fail;		\
 			else (dst) = strdup((tok) + 1);		\
 		}						\
+		else dE("Unrecognized token: '%s'", (tok)-1);		\
 	while(0)
 
 #define matchitem2(tok, first, rest1, dst1, rest2, dst2)		\
 	case first:							\
-		if (strcasecmp((rest1), (tok)+1) == 0) {		\
+		if (strncasecmp((rest1), (tok)+1, strlen(rest1)) == 0) {	\
 			tok += 1+strlen(rest1);				\
 			skipspace(tok);					\
 			if (*(tok) != '=') goto __fail;			\
 			else (dst1) = strdup((tok) + 1);		\
 		}							\
-		else if (strcasecmp((rest2), (tok)+1) == 0) {		\
+		else if (strncasecmp((rest2), (tok)+1, strlen(rest2)) == 0) {	\
 			tok += 1+strlen(rest2);				\
 			skipspace(tok);					\
 			if (*(tok) != '=') goto __fail;			\
 			else (dst2) = strdup((tok) + 1);		\
 		}							\
+		else dE("Unrecognized token: '%s'", (tok));		\
 		while(0)
 
 	tmp = NULL;
 
 	while ((tok = strsep (&copy, ";")) != NULL) {
+		dI("tok: '%s'.\n", tok);
 		switch (tolower(*tok)) {
 			matchitem1(tok, 's',
 				  "erver", info->host); break;
@@ -232,13 +236,20 @@ static int dbURIInfo_parse(dbURIInfo_t *info, const char *conn)
 				oscap_free(tmp);
 			}
 			break;
+
+		case '\0':
+			break;
+		default:
+			dE("Unrecognized token: '%s'", (tok));
+			break;
 		}
 	}
 
-	oscap_free(copy);
+	oscap_free(conn_copy);
 	return (0);
 __fail:
-	oscap_free(copy);
+	dE("Parsing failed.\n");
+	oscap_free(conn_copy);
 	return (-1);
 }
 
@@ -270,30 +281,63 @@ static int dbSQL_eval(const char *engine, const char *version,
 				       (int(*)(void *, void *))&engine_cmp);
 
 		if (sql_dbe == NULL) {
+			SEXP_t *msg = probe_msg_creatf(OVAL_MESSAGE_LEVEL_ERROR,
+				"DB engine not found: %s", engine);
+			probe_cobj_add_msg(probe_ctx_getresult(ctx), msg);
+			SEXP_free(msg);
+			probe_cobj_set_flag(probe_ctx_getresult(ctx), SYSCHAR_FLAG_ERROR);
+			err = 0;
 			dE("DB engine not found: %s\n", engine);
 			goto __exit;
 		}
 
 		if (sql_dbe->b_engine == NULL) {
+			SEXP_t *msg = probe_msg_creatf(OVAL_MESSAGE_LEVEL_ERROR,
+				"DB engine not supported: %s", engine);
+			probe_cobj_add_msg(probe_ctx_getresult(ctx), msg);
+			SEXP_free(msg);
+			probe_cobj_set_flag(probe_ctx_getresult(ctx), SYSCHAR_FLAG_ERROR);
+			err = 0;
 			dE("DB engine not supported: %s\n", engine);
 			goto __exit;
 		}
 
-		if (odbx_init (&sql_dbh, sql_dbe->b_engine,
-			       uriInfo.host, uriInfo.port) != ODBX_ERR_SUCCESS)
-		{
-			dE("odbx_init failed: e=%s, h=%s:%s\n",
-			   sql_dbe->b_engine, uriInfo.host, uriInfo.port);
+		int odbx_res = odbx_init (&sql_dbh, sql_dbe->b_engine,
+				uriInfo.host, uriInfo.port);
+		if (odbx_res != ODBX_ERR_SUCCESS) {
+			const char *error_msg = odbx_error(NULL, odbx_res);
+			dE("odbx_init failed: e=%s, h=%s:%s msg=%s\n",
+				sql_dbe->b_engine, uriInfo.host, uriInfo.port,
+				error_msg != NULL ? error_msg : "(none)");
+			if (odbx_res == -ODBX_ERR_NOTEXIST) {
+				SEXP_t *msg = probe_msg_creatf(OVAL_MESSAGE_LEVEL_ERROR,
+					"odbx_init failed. Please install the opendbx %s backend", engine);
+				probe_cobj_add_msg(probe_ctx_getresult(ctx), msg);
+				SEXP_free(msg);
+				probe_cobj_set_flag(probe_ctx_getresult(ctx), SYSCHAR_FLAG_ERROR);
+				err = 0;
+				fprintf(stderr, "Could not connect to the database. "
+					"Please install the opendbx %s backend.\n",
+					sql_dbe->b_engine);
+			}
 			goto __exit;
 		}
 
 		/* set options */
-
-		if (odbx_bind (sql_dbh, uriInfo.db, uriInfo.user, uriInfo.pass,
-			       ODBX_BIND_SIMPLE) != ODBX_ERR_SUCCESS)
+		odbx_res = odbx_bind(sql_dbh, uriInfo.db, uriInfo.user, uriInfo.pass, ODBX_BIND_SIMPLE);
+		if (odbx_res != ODBX_ERR_SUCCESS)
 		{
+			const char *error_msg = odbx_error(sql_dbh, odbx_res);
+			SEXP_t *msg = probe_msg_creatf(OVAL_MESSAGE_LEVEL_ERROR,
+				"odbx_bind failed. Could not connect to the database '%s': %s",
+				uriInfo.db, error_msg != NULL ? error_msg : "(none)");
+			probe_cobj_add_msg(probe_ctx_getresult(ctx), msg);
+			SEXP_free(msg);
+			probe_cobj_set_flag(probe_ctx_getresult(ctx), SYSCHAR_FLAG_ERROR);
+			err = 0;
 			dE("odbx_bind failed: db=%s, u=%s, p=%s\n",
 			   uriInfo.db, uriInfo.user, uriInfo.pass);
+			odbx_finish(sql_dbh);
 			goto __exit;
 		}
 
@@ -357,7 +401,7 @@ int probe_main(probe_ctx *ctx, void *arg)
 	do {								\
 		SEXP_t *__sval;						\
 									\
-		__sval = probe_obj_getentval (obj, #ent_name, 1);	\
+		__sval = probe_obj_getentval (obj, ent_name, 1);	\
 									\
 		if (__sval == NULL) {					\
 			dE("Missing entity or value: obj=%p, ent=%s\n", obj, #ent_name); \
@@ -393,6 +437,11 @@ int probe_main(probe_ctx *ctx, void *arg)
 	 */
 	err = dbSQL_eval(engine, version, conn, sqlexp, ctx);
 __exit:
+	if (engine != NULL) {
+		__clearmem(conn, strlen(engine));
+		oscap_free(engine);
+	}
+
 	if (sqlexp != NULL) {
 		__clearmem(sqlexp, strlen(sqlexp));
 		oscap_free(sqlexp);
