@@ -46,7 +46,7 @@
 		SEXP_t *___r;					\
 								\
 		if ((___r = probe_ent_getval(ent)) == NULL) {	\
-			_W("entity has no value!\n");		\
+			dW("entity has no value!\n");		\
 			return (NULL);				\
 		} else {					\
 			if (!SEXP_stringp(___r)) {		\
@@ -76,10 +76,6 @@ typedef struct {
 	char *ofts_recurse_path_curpth;
 	dev_t ofts_recurse_path_devid;
 
-	char   **ofts_st_path;       /**< starting paths - NULL terminated */
-	uint16_t ofts_st_path_count; /**< number of starting paths */
-	uint16_t ofts_st_path_index; /**< current starting path */
-
 	pcre       *ofts_path_regex;
 	pcre_extra *ofts_path_regex_extra;
 	uint32_t ofts_path_op;
@@ -116,6 +112,7 @@ typedef struct {
 	size_t file_len;
 	char *path;
 	size_t path_len;
+	unsigned int fts_info;
 } OVAL_FTSENT;
 
 /*
