@@ -36,18 +36,22 @@
 #include <stdarg.h>
 #include <string.h>
 #include <errno.h>
+#include <arpa/inet.h> /* inet_pton() in probe_ent_from_cstr() */
+#include <netinet/in.h>
 
 #include "debug_priv.h"
 #include "_probe-api.h"
 #include "assume.h"
-#include "memusage.h"
-#include "oscap_sysinfo.h"
 #include "oval_probe_impl.h"
 #include "probe/entcmp.h"
+#include "probe/probe.h"
+#include "SEAP/generic/strto.h"
 
 extern probe_rcache_t  *OSCAP_GSYM(pcache);
 extern probe_ncache_t  *OSCAP_GSYM(ncache);
 extern struct id_desc_t OSCAP_GSYM(id_desc);
+extern probe_option_t *OSCAP_GSYM(probe_optdef);
+extern size_t OSCAP_GSYM(probe_optdef_count);
 
 /*
  * items
@@ -57,8 +61,6 @@ SEXP_t *probe_item_creat(const char *name, SEXP_t * attrs, ...)
 	va_list ap;
 	SEXP_t *itm, *ns, *val, *ent;
 
-	_LOGCALL_;
-
 	va_start(ap, attrs);
 
 	itm = probe_item_new(name, attrs);
@@ -102,8 +104,6 @@ SEXP_t *probe_item_new(const char *name, SEXP_t * attrs)
 {
 	SEXP_t *itm, *sid, *attr;
 
-	_LOGCALL_;
-
         /*
          * Allocate space for the ID which will be generated
          * in the icache worker
@@ -129,8 +129,6 @@ SEXP_t *probe_item_attr_add(SEXP_t * item, const char *name, SEXP_t * val)
 {
 	SEXP_t *n_ref, *ns;
 
-	_LOGCALL_;
-
 	n_ref = SEXP_listref_first(item);
 
 	if (SEXP_listp(n_ref)) {
@@ -180,8 +178,6 @@ SEXP_t *probe_item_ent_add(SEXP_t *item, const char *name, SEXP_t *attrs, SEXP_t
 {
 	SEXP_t *ent;
 
-	_LOGCALL_;
-
 	ent = probe_ent_creat1(name, attrs, val);
 	SEXP_list_add(item, ent);
 	SEXP_free(ent);
@@ -194,7 +190,6 @@ int probe_item_setstatus(SEXP_t *obj, oval_syschar_status_t status)
         SEXP_t *r0;
 
 	_A(obj != NULL);
-	_LOGCALL_;
 
 	probe_item_attr_add(obj, "status", r0 = SEXP_number_newi_32((int) status));
         SEXP_free(r0);
@@ -205,7 +200,6 @@ int probe_item_setstatus(SEXP_t *obj, oval_syschar_status_t status)
 int probe_itement_setstatus(SEXP_t *obj, const char *name, uint32_t n, oval_syschar_status_t status)
 {
         SEXP_t *ent_h, *ent_s, *r0;
-	_LOGCALL_;
 
         ent_h = probe_item_getent (obj, name, n);
         ent_s = SEXP_unref (ent_h);
@@ -263,20 +257,24 @@ bool probe_item_filtered(const SEXP_t *item, const SEXP_t *filters)
 				SEXP_free(r0);
 			}
 
-			oscap_free(elm_name);
-			r0 = probe_ent_getattrval(felm, "entity_check");
+			if (SEXP_list_length(elm_res) > 0) {
+				oscap_free(elm_name);
+				r0 = probe_ent_getattrval(felm, "entity_check");
 
-			if (r0 == NULL)
-				ochk = OVAL_CHECK_ALL;
-			else
-				ochk = SEXP_number_geti_32(r0);
+				if (r0 == NULL)
+					ochk = OVAL_CHECK_ALL;
+				else
+					ochk = SEXP_number_geti_32(r0);
 
-			SEXP_free(r0);
+				SEXP_free(r0);
 
-			ores = probe_ent_result_bychk(elm_res, ochk);
+				ores = probe_ent_result_bychk(elm_res, ochk);
+				SEXP_free(elm_res);
+			} else {
+				ores = OVAL_RESULT_FALSE;
+			}
 			SEXP_list_add(ste_res, r0 = SEXP_number_newi_32(ores));
 			SEXP_free(r0);
-			SEXP_free(elm_res);
 		}
 
 		r0 = probe_ent_getattrval(ste, "operator");
@@ -307,8 +305,6 @@ SEXP_t *probe_attr_creat(const char *name, const SEXP_t * val, ...)
 	va_list ap;
 	SEXP_t *list, *ns;
 
-	_LOGCALL_;
-
 	va_start(ap, val);
 	list = SEXP_list_new(NULL);
 
@@ -342,8 +338,6 @@ SEXP_t *probe_obj_creat(const char *name, SEXP_t * attrs, ...)
 	va_list ap;
 	SEXP_t *obj, *ns, *val, *ent;
 
-	_LOGCALL_;
-
 	va_start(ap, attrs);
 
 	obj = probe_obj_new(name, attrs);
@@ -386,8 +380,6 @@ SEXP_t *probe_obj_new(const char *name, SEXP_t * attrs)
 {
 	SEXP_t *obj, *ns;
 
-	_LOGCALL_;
-
 	obj = SEXP_list_new(NULL);
 	ns  = probe_ncache_ref (OSCAP_GSYM(ncache), name);
 
@@ -415,7 +407,6 @@ SEXP_t *probe_obj_getent(const SEXP_t * obj, const char *name, uint32_t n)
 	_A(obj != NULL);
 	_A(name != NULL);
 	_A(n > 0);
-	_LOGCALL_;
 
 	ent = NULL;
 	objents = SEXP_list_rest(obj);
@@ -435,7 +426,7 @@ SEXP_t *probe_obj_getent(const SEXP_t * obj, const char *name, uint32_t n)
 #if !defined(NDEBUG) && defined(SEAP_VERBOSE_DEBUG)
 			char buf[128];
 			SEXP_string_cstr_r(ent_name, buf, sizeof buf);
-			_D("1=\"%s\", 2=\"%s\", n=%u\n", buf, name, n);
+			dI("1=\"%s\", 2=\"%s\", n=%u\n", buf, name, n);
 #endif
 
 			if (SEXP_strcmp(ent_name, name) == 0 && (--n == 0)) {
@@ -456,8 +447,6 @@ SEXP_t *probe_obj_getentval(const SEXP_t * obj, const char *name, uint32_t n)
 {
 	SEXP_t *ent, *val;
 
-	_LOGCALL_;
-
 	ent = probe_obj_getent(obj, name, n);
 	val = probe_ent_getval(ent);
 
@@ -471,8 +460,6 @@ int probe_obj_getentvals(const SEXP_t * obj, const char *name, uint32_t n, SEXP_
 	SEXP_t *ent;
 	int ret;
 
-	_LOGCALL_;
-
 	ent = probe_obj_getent(obj, name, n);
 	ret = probe_ent_getvals(ent, res);
 
@@ -481,14 +468,32 @@ int probe_obj_getentvals(const SEXP_t * obj, const char *name, uint32_t n, SEXP_
 	return (ret);
 }
 
+oval_version_t probe_obj_get_schema_version(const SEXP_t *obj)
+{
+	SEXP_t *sexp_ver;
+	oval_version_t ver;
+
+	if (obj == NULL)
+		return OVAL_VERSION_INVALID;
+	sexp_ver = probe_obj_getattrval(obj, "oval_version");
+
+	if (!SEXP_numberp(sexp_ver)) {
+		SEXP_free(sexp_ver);
+		return OVAL_VERSION_INVALID;
+	}
+
+	ver = SEXP_number_getu_32(sexp_ver);
+	SEXP_free(sexp_ver);
+
+	return ver;
+}
+
 SEXP_t *probe_obj_getattrval(const SEXP_t * obj, const char *name)
 {
 	SEXP_t *obj_name;
 	char name_buf[64 + 1];
 	size_t name_len;
 
-	_LOGCALL_;
-
 	obj_name = SEXP_list_first(obj);
 	name_len = snprintf(name_buf, sizeof name_buf, ":%s", name);
 
@@ -555,7 +560,13 @@ bool probe_obj_attrexists(const SEXP_t * obj, const char *name)
 						return (true);
 					}
 					++i;
-				}
+				} else {
+                                    if (SEXP_strcmp(attr, name_buf + 1) == 0) {
+                                        SEXP_free(attr);
+                                        SEXP_free(obj_name);
+                                        return true;
+                                    }
+                                }
 				++i;
 			}
 
@@ -571,7 +582,6 @@ bool probe_obj_attrexists(const SEXP_t * obj, const char *name)
 int probe_obj_setstatus(SEXP_t * obj, oval_syschar_status_t status)
 {
         SEXP_t *r0;
-	_LOGCALL_;
 
 	probe_item_attr_add(obj, "status", r0 = SEXP_number_newi_32(status));
         SEXP_free(r0);
@@ -592,17 +602,19 @@ size_t probe_obj_getname_r(const SEXP_t * obj, char *buffer, size_t buflen)
 /*
  * collected objects
  */
-SEXP_t *probe_cobj_new(oval_syschar_collection_flag_t flag, SEXP_t *msg_list, SEXP_t *item_list)
+SEXP_t *probe_cobj_new(oval_syschar_collection_flag_t flag, SEXP_t *msg_list, SEXP_t *item_list, SEXP_t *mask_list)
 {
 	SEXP_t *cobj, *r0;
 
 	msg_list = (msg_list == NULL) ? SEXP_list_new(NULL) : SEXP_ref(msg_list);
 	item_list = (item_list == NULL) ? SEXP_list_new(NULL) : SEXP_ref(item_list);
+        mask_list = mask_list == NULL ? SEXP_list_new(NULL) : SEXP_ref(mask_list);
 	cobj = SEXP_list_new(r0 = SEXP_number_newu(flag),
 			     msg_list,
 			     item_list,
+                             mask_list,
 			     NULL);
-	SEXP_vfree(msg_list, item_list, r0, NULL);
+	SEXP_vfree(msg_list, item_list, mask_list, r0, NULL);
 
 	return cobj;
 }
@@ -623,28 +635,18 @@ SEXP_t *probe_cobj_get_msgs(const SEXP_t *cobj)
 	return SEXP_list_nth(cobj, 2);
 }
 
+SEXP_t *probe_cobj_get_mask(const SEXP_t *cobj)
+{
+    return SEXP_list_nth(cobj, 4);
+}
+
 static SEXP_t *probe_item_optimize(const SEXP_t *item);
-static int probe_cobj_memcheck(size_t item_cnt);
 
 int probe_cobj_add_item(SEXP_t *cobj, const SEXP_t *item)
 {
 	SEXP_t *lst, *oitem;
-	size_t item_cnt;
 
 	lst = SEXP_listref_nth(cobj, 3);
-	item_cnt = SEXP_list_length(lst);
-
-	if (probe_cobj_memcheck(item_cnt) != 0) {
-		SEXP_t *msg;
-
-		msg = probe_msg_creat(OVAL_MESSAGE_LEVEL_WARNING, "Object is incomplete due to memory constraints.");
-		probe_cobj_add_msg(cobj, msg);
-		probe_cobj_set_flag(cobj, SYSCHAR_FLAG_INCOMPLETE);
-		SEXP_vfree(lst, msg, NULL);
-
-		return -1;
-	}
-
 	oitem = probe_item_optimize(item);
 	SEXP_list_add(lst, oitem);
 	SEXP_vfree(lst, oitem, NULL);
@@ -903,7 +905,7 @@ SEXP_t *probe_msg_creat(oval_message_level_t level, char *message)
 {
 	SEXP_t *lvl, *str, *msg;
 
-	_D(message);
+	dI("%s\n", message);
 	lvl = SEXP_number_newu(level);
 	str = SEXP_string_newf("%s", message);
 	msg = SEXP_list_new(lvl, str, NULL);
@@ -919,15 +921,13 @@ SEXP_t *probe_msg_creatf(oval_message_level_t level, const char *fmt, ...)
 	char *cstr;
 	SEXP_t *lvl, *str, *msg;
 
-	_LOGCALL_;
-
 	va_start(alist, fmt);
 	len = vasprintf(&cstr, fmt, alist);
 	va_end(alist);
 	if (len < 0)
 		return NULL;
 
-	_D(cstr);
+	dI("%s\n", cstr);
 	str = SEXP_string_new(cstr, len);
 	oscap_free(cstr);
 	lvl = SEXP_number_newu(level);
@@ -945,8 +945,6 @@ SEXP_t *probe_ent_creat(const char *name, SEXP_t * attrs, SEXP_t * val, ...)
 	va_list ap;
 	SEXP_t *ent_list, *ent;
 
-	_LOGCALL_;
-
 	va_start(ap, val);
 	ent_list = SEXP_list_new(NULL);
 
@@ -970,8 +968,6 @@ SEXP_t *probe_ent_creat1(const char *name, SEXP_t * attrs, SEXP_t * val)
 {
 	SEXP_t *ent, *ns;
 
-	_LOGCALL_;
-
 	ent = SEXP_list_new(NULL);
 	ns  = probe_ncache_ref (OSCAP_GSYM(ncache), name);
 
@@ -998,7 +994,6 @@ SEXP_t *probe_ent_creat1(const char *name, SEXP_t * attrs, SEXP_t * val)
 
 SEXP_t *probe_ent_attr_add(SEXP_t * ent, const char *name, SEXP_t * val)
 {
-	_LOGCALL_;
 	return (probe_item_attr_add(ent, name, val));
 }
 
@@ -1007,7 +1002,6 @@ int probe_ent_getvals(const SEXP_t * ent, SEXP_t ** res)
 	SEXP_t *val_lst;
 	int len;
 
-	_LOGCALL_;
 	if (probe_ent_attrexists(ent, "var_ref"))
 		val_lst = SEXP_list_nth(ent, 2);
 	else
@@ -1024,7 +1018,6 @@ int probe_ent_getvals(const SEXP_t * ent, SEXP_t ** res)
 
 SEXP_t *probe_ent_getval(const SEXP_t * ent)
 {
-	_LOGCALL_;
 	if (probe_ent_attrexists(ent, "var_ref")) {
 		SEXP_t *r0, *r1;
 		unsigned int val_idx;
@@ -1052,8 +1045,6 @@ SEXP_t *probe_ent_getattrval(const SEXP_t * ent, const char *name)
 {
 	SEXP_t *attrs;
 
-	_LOGCALL_;
-
 	if (ent == NULL) {
 		errno = EFAULT;
 		return (NULL);
@@ -1097,7 +1088,6 @@ SEXP_t *probe_ent_getattrval(const SEXP_t * ent, const char *name)
 
 bool probe_ent_attrexists(const SEXP_t * ent, const char *name)
 {
-	_LOGCALL_;
 	return probe_obj_attrexists(ent, name);
 }
 
@@ -1106,7 +1096,6 @@ int probe_ent_setdatatype(SEXP_t *ent, oval_datatype_t type)
 	const char *strtype;
 
 	_A(ent != NULL);
-	_LOGCALL_;
 
 	switch (type) {
 	case OVAL_DATATYPE_BOOLEAN:
@@ -1153,7 +1142,6 @@ oval_datatype_t probe_ent_getdatatype(const SEXP_t * ent)
 	const char *str;
 
 	_A(ent != NULL);
-	_LOGCALL_;
 
 	str = SEXP_datatype(ent);
 	if (str != NULL) {
@@ -1177,14 +1165,12 @@ oval_datatype_t probe_ent_getdatatype(const SEXP_t * ent)
 
 int probe_ent_setmask(SEXP_t * ent, bool mask)
 {
-	_LOGCALL_;
 	/* TBI */
 	return (-1);
 }
 
 bool probe_ent_getmask(const SEXP_t * ent)
 {
-	_LOGCALL_;
 	/* TBI */
 	return (false);
 }
@@ -1192,7 +1178,6 @@ bool probe_ent_getmask(const SEXP_t * ent)
 int probe_ent_setstatus(SEXP_t * ent, oval_syschar_status_t status)
 {
         SEXP_t *r0;
-	_LOGCALL_;
 
         probe_item_attr_add (ent, "status", r0 = SEXP_number_newi_32(status));
         SEXP_free(r0);
@@ -1205,8 +1190,6 @@ oval_syschar_status_t probe_ent_getstatus(const SEXP_t * ent)
         SEXP_t *val;
         oval_syschar_status_t sta;
 
-	_LOGCALL_;
-
         val = probe_ent_getattrval (ent, "status");
 
         if (val != NULL) {
@@ -1224,8 +1207,6 @@ char *probe_ent_getname(const SEXP_t * ent)
 	SEXP_t *ent_name;
 	char *name_str;
 
-	_LOGCALL_;
-
 	if (ent == NULL) {
 		errno = EFAULT;
 		return (NULL);
@@ -1270,8 +1251,6 @@ size_t probe_ent_getname_r(const SEXP_t * ent, char *buffer, size_t buflen)
 	SEXP_t *ent_name;
 	size_t name_len;
 
-	_LOGCALL_;
-
 	if (ent == NULL) {
 		errno = EFAULT;
 		return (0);
@@ -1394,48 +1373,6 @@ static SEXP_t *probe_item_optimize(const SEXP_t *item)
 	return SEXP_ref(item);
 }
 
-#define PROBE_RESULT_MEMCHECK_CTRESHOLD  32768  /* item count */
-#define PROBE_RESULT_MEMCHECK_MINFREEMEM 128    /* MiB */
-#define PROBE_RESULT_MEMCHECK_MAXRATIO   0.80   /* max. memory usage ratio - used/total */
-
-/**
- * Return true if the memory constraints are not reached.
- */
-static int probe_cobj_memcheck(size_t item_cnt)
-{
-	if (item_cnt > PROBE_RESULT_MEMCHECK_CTRESHOLD) {
-		struct memusage mu;
-		struct sysinfo  si;
-		double c_ratio;
-
-		// todo: add an error message to the collected object?
-
-		if (memusage (&mu) != 0)
-			return (-1);
-
-		if (oscap_sysinfo (&si) != 0)
-			return (-1);
-
-		c_ratio = (double)mu.mu_data/(double)((si.totalram * si.mem_unit) / 1024);
-
-		if (c_ratio > PROBE_RESULT_MEMCHECK_MAXRATIO) {
-			dW("Memory usage ratio limit reached! limit=%f, current=%f\n",
-			   PROBE_RESULT_MEMCHECK_MAXRATIO, c_ratio);
-			errno = ENOMEM;
-			return (-1);
-		}
-
-		if (((si.freeram * si.mem_unit) / 1048576) < PROBE_RESULT_MEMCHECK_MINFREEMEM) {
-			dW("Minimum free memory limit reached! limit=%zu, current=%zu\n",
-			   PROBE_RESULT_MEMCHECK_MINFREEMEM, (si.freeram * si.mem_unit) / 1048576);
-			errno = ENOMEM;
-			return (-1);
-		}
-	}
-
-	return (0);
-}
-
 SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attributes[],
                           /* const char *value_name, oval_datatype_t value_type, void *value, */ ...)
 {
@@ -1552,6 +1489,7 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
 			   value_type, oval_datatype_get_text(value_type), value_name);
                         SEXP_free(item);
 
+			va_end(ap);
                         return (NULL);
                 }
 
@@ -1644,11 +1582,13 @@ int probe_item_add_msg(SEXP_t *item, oval_message_level_t msglvl, char *msgfmt,
 
     if (msg_length < 0) {
 	dE("vsnprintf failed! errno=%u, %s.\n", errno, strerror(errno));
+	va_end(ap);
 	return (-1);
     }
 
     if ((size_t)msg_length >= sizeof msg_buffer) {
 	dE("message too long!\n");
+	va_end(ap);
 	return (-1);
     }
 
@@ -1666,3 +1606,161 @@ int probe_item_add_msg(SEXP_t *item, oval_message_level_t msglvl, char *msgfmt,
 
     return (0);
 }
+
+SEXP_t *probe_entval_from_cstr(oval_datatype_t type,
+                               const char *value, size_t vallen)
+{
+  SEXP_t *ent_val = NULL;
+
+  if (value == NULL || vallen == 0)
+    return NULL;
+
+	switch (type) {
+	case OVAL_DATATYPE_FLOAT:
+	{
+		double val;
+		char *end = NULL;
+
+		val = strto_double(value, vallen, &end);
+		ent_val = SEXP_number_newf(val);
+
+	}	break;
+	case OVAL_DATATYPE_INTEGER:
+	{
+		int64_t val;
+		char *end;
+
+		val = strto_int64(value, vallen, &end, 10);
+		ent_val = SEXP_number_newi_64(val);
+
+	}	break;
+	case OVAL_DATATYPE_BOOLEAN:
+		switch(vallen) {
+		case 1:
+			switch(*value)
+			{
+			case '1':
+				ent_val = SEXP_number_newb(true);
+				break;
+			case '0':
+				ent_val = SEXP_number_newb(false);
+				break;
+			}
+			break;
+		case 4:
+			if (strncasecmp(value, "true", 4) == 0)
+				ent_val = SEXP_number_newb(true);
+			break;
+		case 5:
+			if (strncasecmp(value, "false", 5) == 0)
+				ent_val = SEXP_number_newb(false);
+			break;
+		}
+
+		if (ent_val == NULL)
+			return NULL;
+		break;
+
+
+	case OVAL_DATATYPE_IPV4ADDR:
+	{
+		struct in_addr ip4;
+
+		if (inet_pton(AF_INET, value, &ip4) != 1)
+			return NULL;
+	}	break;
+	case OVAL_DATATYPE_IPV6ADDR:
+	{
+		struct in6_addr ip6;
+
+		if (inet_pton(AF_INET6, value, &ip6) != 1)
+			return NULL;
+	}	break;
+
+	case OVAL_DATATYPE_EVR_STRING:
+	case OVAL_DATATYPE_FILESET_REVISION:
+	case OVAL_DATATYPE_IOS_VERSION:
+	case OVAL_DATATYPE_STRING:
+	case OVAL_DATATYPE_VERSION:
+		break;
+
+	case OVAL_DATATYPE_BINARY:
+	case OVAL_DATATYPE_SEXP:
+	case OVAL_DATATYPE_UNKNOWN:
+	case OVAL_DATATYPE_STRING_M:
+	case OVAL_DATATYPE_RECORD:
+	default:
+		return NULL;
+	}
+
+	/*
+	 * If we got here and ent_val is still NULL, then
+	 * no special conversion procedure is needed and
+	 * we can simply create an SEXP string...
+	 */
+	if (ent_val == NULL)
+		ent_val = SEXP_string_new(value, vallen);
+
+  return ent_val;
+}
+
+SEXP_t *probe_ent_from_cstr(const char *name, oval_datatype_t type,
+                            const char *value, size_t vallen)
+{
+	SEXP_t *ent = NULL, *ent_val = NULL;
+
+	if (name == NULL || value == NULL || vallen == 0)
+		return NULL;
+
+  ent_val = probe_entval_from_cstr(type, value, vallen);
+
+  if (ent_val == NULL)
+    return NULL;
+  
+	/* Create the entity... */
+	ent = probe_ent_creat1(name, NULL, ent_val);	
+	SEXP_free(ent_val);
+
+	/* ...and annotate with the specified OVAL datatype */
+	if (probe_ent_setdatatype(ent, type) != 0) {
+		SEXP_free(ent);
+		return NULL;
+	}
+
+	return ent;
+}
+
+SEXP_t *probe_obj_getmask(SEXP_t *obj)
+{
+    SEXP_t *objents, *ent, *ent_name, *mask;
+
+    SEXP_VALIDATE(obj);
+
+    if (obj == NULL)
+       return NULL;
+
+    ent     = NULL;
+    mask    = SEXP_list_new(NULL);
+    objents = SEXP_list_rest(obj);
+
+    SEXP_list_foreach(ent, objents) {
+        ent_name = SEXP_list_first(ent);
+
+        if (SEXP_listp(ent_name)) {
+            SEXP_t *nr;
+
+            nr = SEXP_list_first(ent_name);
+            SEXP_free(ent_name);
+            ent_name = nr;
+
+            if (probe_ent_attrexists(ent, "mask"))
+                SEXP_list_add(mask, ent_name);
+        }
+        SEXP_free(ent_name);
+    }
+
+    SEXP_free(objents);
+    return (mask);
+}
+
+/// @}
