@@ -43,6 +43,7 @@
 #include <sys/types.h>
 #include <attr/xattr.h>
 
+#include <probe/probe.h>
 #include <probe/option.h>
 #include "probe/entcmp.h"
 #include "oval_fts.h"
@@ -209,7 +210,7 @@ void *probe_init (void)
 	probe_setoption(PROBEOPT_VARREF_HANDLING, false, "path");
 	probe_setoption(PROBEOPT_VARREF_HANDLING, false, "filename");
 #endif
-		probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, true);
+		probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, PROBE_OFFLINE_CHROOT);
         return (NULL);
 }
 
