@@ -83,6 +83,7 @@
 /* SEAP */
 #include <seap.h>
 #include <probe-api.h>
+#include <probe/probe.h>
 #include <probe/option.h>
 #include "probe/entcmp.h"
 #include <alloc.h>
@@ -111,6 +112,26 @@ struct rpminfo_global {
         pthread_mutex_t mutex;
 };
 
+#define RPMINFO_LOCK	  \
+	do { \
+		int prev_cancel_state = -1; \
+		if (pthread_mutex_lock(&g_rpm.mutex) != 0) { \
+			dE("Can't lock mutex\n"); \
+			return (-1); \
+		} \
+		pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, &prev_cancel_state); \
+	} while(0)
+
+#define RPMINFO_UNLOCK	  \
+	do { \
+		int prev_cancel_state = -1; \
+		if (pthread_mutex_unlock(&g_rpm.mutex) != 0) { \
+			dE("Can't unlock mutex. Aborting...\n"); \
+			abort(); \
+		} \
+		pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &prev_cancel_state); \
+	} while(0)
+
 static struct rpminfo_global g_rpm;
 static const char g_keyid_regex_string[] = "Key ID [a-fA-F0-9]{16}";
 static regex_t g_keyid_regex;
@@ -130,6 +151,7 @@ static void pkgh2rep (Header h, struct rpminfo_rep *r)
 {
         errmsg_t rpmerr;
         char *str, *sid;
+	char *epoch_override = NULL;
         size_t len;
 	regmatch_t keyid_match[1];
 
@@ -138,26 +160,19 @@ static void pkgh2rep (Header h, struct rpminfo_rep *r)
 
         r->name = headerFormat (h, "%{NAME}", &rpmerr);
         r->arch = headerFormat (h, "%{ARCH}", &rpmerr);
-        str     = headerFormat (h, "%{EPOCH}", &rpmerr);
-
-        if (strcmp (str, "(none)") == 0) {
-                str    = oscap_realloc (str, sizeof (char) * 2);
-                str[0] = '0';
-                str[1] = '\0';
-        }
-
-        r->epoch   = str;
+        r->epoch = headerFormat (h, "%{EPOCH}", &rpmerr);
         r->release = headerFormat (h, "%{RELEASE}", &rpmerr);
         r->version = headerFormat (h, "%{VERSION}", &rpmerr);
-	snprintf(r->extended_name, 1024, "%s-%s:%s-%s.%s", r->name, r->epoch, r->version, r->release, r->arch);
+	epoch_override = oscap_streq(r->epoch, "(none)") ? "0" : r->epoch;
+	snprintf(r->extended_name, 1024, "%s-%s:%s-%s.%s", r->name, epoch_override, r->version, r->release, r->arch);
 
-        len = (strlen (r->epoch)   +
+	len = (strlen(epoch_override) +
                strlen (r->release) +
                strlen (r->version) + 2);
 
         str = oscap_alloc (sizeof (char) * (len + 1));
         snprintf (str, len + 1, "%s:%s-%s",
-                  r->epoch,
+		epoch_override,
                   r->version,
                   r->release);
 
@@ -201,7 +216,7 @@ static int get_rpminfo (struct rpminfo_req *req, struct rpminfo_rep **rep)
 	Header pkgh;
 	int ret = 0, i;
 
-        pthread_mutex_lock (&(g_rpm.mutex));
+        RPMINFO_LOCK;
 
         ret = -1;
 
@@ -282,17 +297,24 @@ static int get_rpminfo (struct rpminfo_req *req, struct rpminfo_rep **rep)
 
 	match = rpmdbFreeIterator (match);
 ret:
-        pthread_mutex_unlock (&(g_rpm.mutex));
+        RPMINFO_UNLOCK;
         return (ret);
 }
 
 void *probe_init (void)
 {
+	probe_offline_flags offline_mode = PROBE_OFFLINE_NONE;
+
         if (rpmReadConfigFiles ((const char *)NULL, (const char *)NULL) != 0) {
                 dI("rpmReadConfigFiles failed: %u, %s.\n", errno, strerror (errno));
                 return (NULL);
         }
 
+        probe_getoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, NULL, &offline_mode);
+        if (offline_mode & PROBE_OFFLINE_RPMDB) {
+	        addMacro(NULL, "_dbpath", NULL, getenv("OSCAP_PROBE_RPMDB_PATH"), 0);
+        }
+
         g_rpm.rpmts = rpmtsCreate();
         pthread_mutex_init (&(g_rpm.mutex), NULL);
 
@@ -301,7 +323,7 @@ void *probe_init (void)
 		return NULL;
 	}
 
-	probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, true);
+	probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, PROBE_OFFLINE_CHROOT|PROBE_OFFLINE_RPMDB);
 
         return ((void *)&g_rpm);
 }
