@@ -97,20 +97,24 @@ struct rpmverify_global {
 
 static struct rpmverify_global g_rpm;
 
-#define RPMVERIFY_LOCK					  \
-	do {						    \
-		if (pthread_mutex_lock(&g_rpm.mutex) != 0) {    \
-			dE("Can't lock mutex\n");	       \
-			return (-1);			    \
-		}					       \
+#define RPMVERIFY_LOCK	  \
+	do { \
+		int prev_cancel_state = -1; \
+		if (pthread_mutex_lock(&g_rpm.mutex) != 0) { \
+			dE("Can't lock mutex\n"); \
+			return (-1); \
+		} \
+		pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, &prev_cancel_state); \
 	} while(0)
 
-#define RPMVERIFY_UNLOCK						\
-	do {							    \
-		if (pthread_mutex_unlock(&g_rpm.mutex) != 0) {	  \
-			dE("Can't unlock mutex. Aborting...\n");	\
-			abort();					\
-		}						       \
+#define RPMVERIFY_UNLOCK	  \
+	do { \
+		int prev_cancel_state = -1; \
+		if (pthread_mutex_unlock(&g_rpm.mutex) != 0) { \
+			dE("Can't unlock mutex. Aborting...\n"); \
+			abort(); \
+		} \
+		pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &prev_cancel_state); \
 	} while(0)
 
 /* modify passed-in iterator to test also given entity */
@@ -228,8 +232,6 @@ static int rpmverify_collect(probe_ctx *ctx,
 		COMPARE_ENT(name);
 
 		res.epoch = headerFormat(pkgh, "%{EPOCH}", &rpmerr);
-		if (strcmp(res.epoch, "(none)") == 0)
-			res.epoch = "0";
 		COMPARE_ENT(epoch);
 
 		res.version = headerFormat(pkgh, "%{VERSION}", &rpmerr);
@@ -238,7 +240,9 @@ static int rpmverify_collect(probe_ctx *ctx,
 		COMPARE_ENT(release);
 		res.arch = headerFormat(pkgh, "%{ARCH}", &rpmerr);
 		COMPARE_ENT(arch);
-		snprintf(res.extended_name, 1024, "%s-%s:%s-%s.%s", res.name, res.epoch, res.version, res.release, res.arch);
+		snprintf(res.extended_name, 1024, "%s-%s:%s-%s.%s", res.name,
+			oscap_streq(res.epoch, "(none)") ? "0" : res.epoch,
+			res.version, res.release, res.arch);
 
 		/*
 		 * Inspect package files & directories
