@@ -67,26 +67,35 @@
 #include <fcntl.h>
 #include <sched.h>
 #include <time.h>
-#ifdef HAVE_SELINUX
+
+#ifdef HAVE_PROC_DEVNAME_H
+ #include <proc/devname.h>
+#else
+ #include "process58-devname.h"
+#endif
+
+#ifdef HAVE_SELINUX_SELINUX_H
 #include <selinux/selinux.h>
 #include <selinux/context.h>
 #endif
-#ifdef HAVE_LIBCAP
+#ifdef HAVE_SYS_CAPABILITY_H
 #include <ctype.h>
 #include <sys/types.h>
 
-#if LIBCAP_VERSION == 1
+#ifndef HAVE_CAP_GET_PID // we don't have cap_get_pid => assume libcap version == 1
 #undef _POSIX_SOURCE
+#define LIBCAP_VERSION 1
 #include <sys/capability.h>
 #define CAP_LAST_CAP CAP_AUDIT_CONTROL
 extern char const *_cap_names[];
 #else
+#define LIBCAP_VERSION 2
 #include <sys/capability.h>
 #endif
 
 #include "util.h"
 #include "process58-capability.h"
-#endif
+#endif /* HAVE_SYS_CAPABILITY_H */
 
 #include "seap.h"
 #include "probe-api.h"
@@ -104,10 +113,10 @@ struct result_info {
 	int ruid;
         const char *scheduling_class;
         const char *start_time;
-        int tty;
+        const char *tty;
 	int user_id;
 	int exec_shield;
-	int loginuid;
+	unsigned loginuid;
 	char **posix_capability;
 	const char *selinux_domain_label;
 	int session_id;
@@ -115,7 +124,7 @@ struct result_info {
 
 static void report_finding(struct result_info *res, probe_ctx *ctx)
 {
-        SEXP_t *item, se_tty_mem;
+        SEXP_t *item;
 
         item = probe_item_create(OVAL_UNIX_PROCESS58, NULL,
                                  "command_line", OVAL_DATATYPE_STRING, res->command_line,
@@ -126,18 +135,16 @@ static void report_finding(struct result_info *res, probe_ctx *ctx)
 				 "ruid",         OVAL_DATATYPE_INTEGER, (int64_t) res->ruid,
                                  "scheduling_class", OVAL_DATATYPE_STRING, res->scheduling_class,
                                  "start_time",   OVAL_DATATYPE_STRING, res->start_time,
-                                 "tty",          OVAL_DATATYPE_SEXP, SEXP_string_newf_r(&se_tty_mem, "%d", res->tty),
+                                 "tty",          OVAL_DATATYPE_STRING, res->tty,
                                  "user_id",      OVAL_DATATYPE_INTEGER, (int64_t)res->user_id,
                                  "exec_shield",  OVAL_DATATYPE_BOOLEAN, (int64_t)res->exec_shield,
-                                 "loginuid",     OVAL_DATATYPE_INTEGER, (int64_t)res->user_id,
+                                 "loginuid",     OVAL_DATATYPE_INTEGER, (int64_t)res->loginuid,
 				 "posix_capability", OVAL_DATATYPE_STRING_M, res->posix_capability,
 				 "selinux_domain_label", OVAL_DATATYPE_STRING, res->selinux_domain_label,
-				 "session_id", OVAL_DATATYPE_INTEGER, 0,
+                                 "session_id", OVAL_DATATYPE_INTEGER, (int64_t)res->session_id,
                                  NULL);
 
         probe_item_collect(ctx, item);
-
-        SEXP_free_r(&se_tty_mem);
 }
 
 #if defined(__linux__)
@@ -204,12 +211,15 @@ static int get_uids(int pid, struct result_info *r)
 		fclose(sf);
 	}
 
+	/* we get session id from /pros/id/stat (same as ps) */
+	/*
 	snprintf(buf, sizeof(buf), "/proc/%d/sessionid", pid);
 	sf = fopen(buf, "rt");
 	if (sf) {
 		fscanf(sf, "%d", &r->session_id);
 		fclose(sf);
 	}
+	*/
 
 	return 0;
 }
@@ -233,7 +243,7 @@ static char *convert_time(unsigned long long t, char *tbuf, int tb_size)
 }
 
 static char *get_selinux_label(int pid) {
-#ifdef HAVE_SELINUX
+#ifdef HAVE_SELINUX_SELINUX_H
 	char *selinux_label;
 	security_context_t pid_context;
 	context_t context;
@@ -244,18 +254,18 @@ static char *get_selinux_label(int pid) {
 		return NULL;
 	}
 	context = context_new(pid_context);
-	selinux_label = strdup(context_str(context));
+	selinux_label = strdup(context_type_get(context));
 	context_free(context);
 	freecon(pid_context);
 	return selinux_label;
 
 #else
 	return NULL;
-#endif
+#endif /* HAVE_SELINUX_SELINUX_H */
 }
 
 static char **get_posix_capability(int pid) {
-#ifdef HAVE_LIBCAP
+#ifdef HAVE_SYS_CAPABILITY_H
 	cap_t pid_caps;
 	char *cap_name, **ret = NULL;
 	unsigned cap_value, ret_index = 0;
@@ -367,7 +377,7 @@ static int read_process(SEXP_t *cmd_ent, SEXP_t *pid_ent, probe_ctx *ctx)
 	while (( ent = readdir(d) )) {
 		int fd, len;
 		char buf[256];
-		char *tmp, cmd[16], state;
+		char *tmp, cmd[16], state, tty_dev[128];
 		int pid, ppid, pgrp, session, tty_nr, tpgid;
 		unsigned flags, sched_policy;
 		unsigned long minflt, cminflt, majflt, cmajflt, uutime, ustime;
@@ -463,11 +473,16 @@ static int read_process(SEXP_t *cmd_ent, SEXP_t *pid_ent, probe_ctx *ctx)
 			proc = localtime(&s_time);
 
 			// Select format based on how long we've been running
-			fmt = "%H:%M";
-			if (tday != proc->tm_yday)
+			//
+			// FROM THE SPEC:
+			// "This is the time of day the process started formatted in HH:MM:SS if
+			// the same day the process started or formatted as MMM_DD (Ex.: Feb_5)
+			// if process started the previous day or further in the past."
+			//
+			if (tday != proc->tm_yday || tyear != proc->tm_year)
 				fmt = "%b_%d";
-			if (tyear != proc->tm_year)
-				fmt = "%Y";
+			else
+				fmt = "%H:%M:%S";
 			strftime(sbuf, sizeof(sbuf), fmt, proc);
 
 			r.command_line = cmd;
@@ -476,7 +491,10 @@ static int read_process(SEXP_t *cmd_ent, SEXP_t *pid_ent, probe_ctx *ctx)
 			r.ppid = ppid;
 			r.priority = priority;
 			r.start_time = sbuf;
-			r.tty = tty_nr;
+
+			dev_to_tty(tty_dev, sizeof(tty_dev), (dev_t) tty_nr, pid, ABBREV_DEV);
+			r.tty = tty_dev;
+
 			r.exec_shield = (get_exec_shield_status(pid) > 0);
 
 			selinux_domain_label = get_selinux_label(pid);
@@ -485,6 +503,8 @@ static int read_process(SEXP_t *cmd_ent, SEXP_t *pid_ent, probe_ctx *ctx)
 			posix_capabilities = get_posix_capability(pid);
 			r.posix_capability = posix_capabilities;
 
+			r.session_id = session;
+
 			get_uids(pid, &r);
 			report_finding(&r, ctx);
 
@@ -619,23 +639,18 @@ static int read_process(SEXP_t *cmd_ent, probe_ctx *ctx)
 			proc = localtime(&s_time);
 
 			// Select format based on how long we've been running
-			fixfmt_year = 0;
-			fmt = "%H:%M";
-			if (tday != proc->tm_yday)
-				fmt = "%b%d";
-			if (tyear != proc->tm_year)
-				fmt = "%Y";
-				fixfmt_year = 1;
+			//
+			// FROM THE SPEC:
+			// "This is the time of day the process started formatted in HH:MM:SS if
+			// the same day the process started or formatted as MMM_DD (Ex.: Feb_5)
+			// if process started the previous day or further in the past."
+			//
+			if (tday != proc->tm_yday || tyear != proc->tm_year)
+				fmt = "%b_%d";
+			else
+				fmt = "%H:%M:%S";
 			strftime(sbuf, sizeof(sbuf), fmt, proc);
 
-			/* Fixing format from MMMYY to MMM_YY */
-			if (fixfmt_year == 1) {
-				sbuf[6] = '\0';
-				sbuf[5] = sbuf[4];
-				sbuf[4] = sbuf[3];
-				sbuf[3] = '_';
-			}
-
 			r.command_line = psinfo->pr_fname;
 			r.exec_time = convert_time(psinfo->pr_time.tv_sec, tbuf, sizeof(tbuf));
 			r.pid = psinfo->pr_pid;
@@ -643,7 +658,7 @@ static int read_process(SEXP_t *cmd_ent, probe_ctx *ctx)
 			r.priority = (psinfo->pr_lwp).pr_pri;
 			r.ruid = psinfo->pr_uid;
 			r.start_time = sbuf;
-			r.tty = psinfo->pr_ttydev;
+			r.tty = oscap_sprintf("%s", psinfo->pr_ttydev);
 			r.user_id = psinfo->pr_euid;
 			report_finding(&r, ctx);
 		}
