@@ -42,7 +42,6 @@
 #include "oval_results.h"
 #include "oval_variables.h"
 #include "oval_probe.h"
-#include "reporter.h"
 
 struct oval_agent_session;
 
@@ -60,6 +59,19 @@ typedef struct oval_agent_session oval_agent_session_t;
  */
 oval_agent_session_t * oval_agent_new_session(struct oval_definition_model * model, const char * name);
 
+/**
+ * Retrieves OVAL definition model associated with given session
+ */
+struct oval_definition_model* oval_agent_get_definition_model(oval_agent_session_t* ag_sess);
+
+/**
+ * Set a product name for the provided agent session. The
+ * product name should be used for all newly created OVAL documents. If
+ * there already are some models in the session, they are modified as
+ * well.
+ */
+void oval_agent_set_product_name(oval_agent_session_t *, char *);
+
 /**
  * Probe the system and evaluate specified definition
  * @return 0 on success; -1 error; 1 warning
@@ -72,6 +84,12 @@ int oval_agent_eval_definition(oval_agent_session_t *, const char *);
  */
 int oval_agent_get_definition_result(oval_agent_session_t *, const char *, oval_result_t *);
 
+/**
+ * Get the OVAL result definition from an agent session
+ * @return NULL if not found
+ */
+struct oval_result_definition * oval_agent_get_result_definition(oval_agent_session_t *ag_sess, const char *id);
+
 /**
  * Clean resuls that were generated in this agent session
  */
@@ -82,11 +100,13 @@ int oval_agent_reset_session(oval_agent_session_t * ag_sess);
  */
 int oval_agent_abort_session(oval_agent_session_t *ag_sess);
 
+typedef int (*agent_reporter)(const struct oval_result_definition * res_def, void *arg);
+
 /**
  * Probe and evaluate all definitions from the content, call the callback functions upon single evaluation
  * @return 0 on success; -1 error; 1 warning
  */
-int oval_agent_eval_system(oval_agent_session_t * ag_sess, oscap_reporter cb, void *arg);
+int oval_agent_eval_system(oval_agent_session_t * ag_sess, agent_reporter cb, void *arg);
 
 /**
  * Get a result model from agent session
@@ -104,8 +124,8 @@ void oval_agent_destroy_session(oval_agent_session_t * ag_sess);
 
 
 /**
- * @) END OVALDEF
- * @) END OVALAGENT
+ * @} END OVALDEF
+ * @} END OVALAGENT
  */
 #endif				/**OVAL_AGENT_API_H_ */
 
