@@ -1,5 +1,5 @@
 /**
- * @file   oval_probe_h
+ * @file   oval_probe.h
  * @brief  OVAL probe interface API public header
  * @author "Daniel Kopecek" <dkopecek@redhat.com>
  *
@@ -31,6 +31,7 @@
 #ifndef OVAL_PROBE_H
 #define OVAL_PROBE_H
 
+#include <stdio.h>
 #include <stdarg.h>
 #include <stdint.h>
 #include "oval_definitions.h"
@@ -83,4 +84,6 @@ int oval_probe_query_variable(oval_probe_session_t *sess, struct oval_variable *
 
 void oval_probe_meta_list(FILE *output, int flags);
 
+const char *oval_probe_ext_getdir(void);
 #endif				/* OVAL_PROBE_H */
+/// @}
