@@ -147,7 +147,9 @@ typedef enum {
 /// ESX subtypes
 typedef enum {
 	OVAL_ESX_PATCH = OVAL_FAMILY_ESX + 1,
-	OVAL_ESX_VERSION = OVAL_FAMILY_ESX + 2
+	OVAL_ESX_PATCH56 = OVAL_FAMILY_ESX + 2,
+	OVAL_ESX_VERSION = OVAL_FAMILY_ESX + 3,
+	OVAL_ESX_VISDKMANAGEDOBJECT = OVAL_FAMILY_ESX + 4
 } oval_esx_subtype_t;
 
 /// FreeBSD subtypes
@@ -161,7 +163,10 @@ typedef enum {
 	OVAL_HPUX_PATCH_53 = OVAL_FAMILY_HPUX + 2,
 	OVAL_HPUX_PATCH = OVAL_FAMILY_HPUX + 3,
 	OVAL_HPUX_SOFTWARE_LIST = OVAL_FAMILY_HPUX + 4,
-	OVAL_HPUX_TRUSTED_ACCOUNTS = OVAL_FAMILY_HPUX + 5
+	OVAL_HPUX_TRUSTED_ACCOUNTS = OVAL_FAMILY_HPUX + 5,
+	OVAL_HPUX_NDD = OVAL_FAMILY_HPUX + 6,
+	OVAL_HPUX_SWLIST = OVAL_FAMILY_HPUX + 7,
+	OVAL_HPUX_TRUSTED = OVAL_FAMILY_HPUX + 8
 } oval_hpux_subtype_t;
 
 /// Platform independent subtypes
@@ -202,8 +207,11 @@ typedef enum {
         OVAL_LINUX_PARTITION = OVAL_FAMILY_LINUX + 5,
 	OVAL_LINUX_IFLISTENERS = OVAL_FAMILY_LINUX + 6,
 	OVAL_LINUX_RPMVERIFY = OVAL_FAMILY_LINUX + 7,
+	OVAL_LINUX_RPMVERIFYFILE = OVAL_FAMILY_LINUX + 71,
+	OVAL_LINUX_RPMVERIFYPACKAGE = OVAL_FAMILY_LINUX + 72,
 	OVAL_LINUX_SELINUXBOOLEAN = OVAL_FAMILY_LINUX + 8,
-	OVAL_LINUX_SELINUXSECURITYCONTEXT = OVAL_FAMILY_LINUX + 9
+	OVAL_LINUX_SELINUXSECURITYCONTEXT = OVAL_FAMILY_LINUX + 9,
+	OVAL_LINUX_INET_LISTENING_SERVER = OVAL_FAMILY_LINUX + 102,
 } oval_linux_subtype_t;
 
 /// MacOS subtypes
@@ -225,7 +233,10 @@ typedef enum {
 	OVAL_SOLARIS_ISAINFO = OVAL_FAMILY_SOLARIS + 1,
 	OVAL_SOLARIS_PACKAGE = OVAL_FAMILY_SOLARIS + 2,
 	OVAL_SOLARIS_PATCH = OVAL_FAMILY_SOLARIS + 3,
-	OVAL_SOLARIS_SMF = OVAL_FAMILY_SOLARIS + 4
+	OVAL_SOLARIS_SMF = OVAL_FAMILY_SOLARIS + 4,
+	OVAL_SOLARIS_PATCH54 = OVAL_FAMILY_SOLARIS + 5,
+	OVAL_SOLARIS_NDD = OVAL_FAMILY_SOLARIS + 6,
+	OVAL_SOLARIS_PACKAGECHECK = OVAL_FAMILY_SOLARIS + 7
 } oval_solaris_subtype_t;
 
 /// Unix subtypes
