@@ -1,5 +1,5 @@
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * Copyright (C) 2010 Tresys Technology, LLC
  * All Rights Reserved.
  *
@@ -20,6 +20,7 @@
  * Authors:
  *      Lukas Kuklinek <lkuklinek@redhat.com>
  * 	Josh Adams <jadams@tresys.com>
+ * 	Šimon Lukašík
  */
 
 #ifdef HAVE_CONFIG_H
@@ -60,6 +61,14 @@ const struct oscap_string_map XCCDF_LEVEL_MAP[] = {
 	{XCCDF_LEVEL_NOT_DEFINED, NULL}
 };
 
+const struct oscap_string_map XCCDF_BOOLOP_MAP[] = {
+	{XCCDF_OPERATOR_AND, "AND"},
+	{XCCDF_OPERATOR_OR, "OR"},
+	{XCCDF_OPERATOR_AND, "and"},
+	{XCCDF_OPERATOR_OR, "or"},
+	{0, NULL}
+};
+
 static const struct oscap_string_map XCCDF_STATUS_MAP[] = {
 	{XCCDF_STATUS_ACCEPTED, "accepted"},
 	{XCCDF_STATUS_DEPRECATED, "deprecated"},
@@ -601,12 +610,6 @@ xmlNode *xccdf_ident_to_dom(struct xccdf_ident *ident, xmlDoc *doc, xmlNode *par
 	return ident_node;
 }
 
-static const struct oscap_string_map XCCDF_BOOLOP_MAP[] = {
-	{XCCDF_OPERATOR_AND, "AND"},
-	{XCCDF_OPERATOR_OR, "OR"},
-	{0, NULL}
-};
-
 xmlNode *xccdf_check_to_dom(struct xccdf_check *check, xmlDoc *doc, xmlNode *parent, const struct xccdf_version_info* version_info)
 {
 	xmlNs *ns_xccdf = xmlSearchNsByHref(doc, parent,
