@@ -1,5 +1,5 @@
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -167,9 +167,14 @@ struct xccdf_profile_item {
 };
 
 struct xccdf_tailoring {
+	// optional, only relevant when Tailoring is saved as a root element
+	char *id;
+
 	// The ref is "just informative" according to the spec, we never
 	// interpret it and just load and save it as a string.
 	char *benchmark_ref;
+	// Also just informative
+	char *benchmark_ref_version;
 
 	struct oscap_list *statuses;
 	struct oscap_list *dc_statuses;
@@ -408,6 +413,7 @@ struct xccdf_plain_text {
 extern const struct oscap_string_map XCCDF_LEVEL_MAP[];
 extern const struct oscap_string_map XCCDF_ROLE_MAP[];
 extern const struct oscap_string_map XCCDF_OPERATOR_MAP[];
+extern const struct oscap_string_map XCCDF_BOOLOP_MAP[];
 extern const struct oscap_string_map XCCDF_STRATEGY_MAP[];
 extern const struct oscap_string_map XCCDF_FACT_TYPE_MAP[];
 extern const struct oscap_string_map XCCDF_RESULT_MAP[];
@@ -438,8 +444,6 @@ struct xccdf_profile *xccdf_benchmark_get_profile_by_id(struct xccdf_benchmark *
 struct xccdf_result *xccdf_benchmark_get_result_by_id(struct xccdf_benchmark *benchmark, const char *testresult_id);
 bool xccdf_add_item(struct oscap_list *list, struct xccdf_item *parent, struct xccdf_item *item, const char *prefix);
 
-struct xccdf_tailoring *xccdf_tailoring_new(void);
-void xccdf_tailoring_free(struct xccdf_tailoring *tailoring);
 struct xccdf_tailoring *xccdf_tailoring_parse(xmlTextReaderPtr reader, struct xccdf_item* benchmark);
 xmlNodePtr xccdf_tailoring_to_dom(struct xccdf_tailoring *tailoring, xmlDocPtr doc, xmlNodePtr parent, const struct xccdf_version_info *version_info);
 
