@@ -1,5 +1,5 @@
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * Copyright (C) 2010 Tresys Technology, LLC
  * All Rights Reserved.
  *
@@ -20,6 +20,7 @@
  * Authors:
  *      Lukas Kuklinek <lkuklinek@redhat.com>
  *      Josh Adams <jadams@tresys.com>
+ *      Šimon Lukašík
  */
 
 #ifdef HAVE_CONFIG_H
@@ -271,8 +272,9 @@ void xccdf_group_free(struct xccdf_item *group)
 struct xccdf_item *xccdf_rule_new_internal(struct xccdf_item *parent)
 {
 	struct xccdf_item *rule = xccdf_item_new(XCCDF_RULE, parent);
-	//rule->sub.rule.role = XCCDF_ROLE_FULL;
-	//rule->sub.rule.severity = XCCDF_UNKNOWN;
+	rule->sub.rule.role = 0;
+	rule->sub.rule.severity = 0;
+
 	rule->sub.rule.idents = oscap_list_new();
 	rule->sub.rule.checks = oscap_list_new();
 	rule->sub.rule.requires = oscap_list_new();
@@ -280,6 +282,7 @@ struct xccdf_item *xccdf_rule_new_internal(struct xccdf_item *parent)
 	rule->sub.rule.profile_notes = oscap_list_new();
 	rule->sub.rule.fixes = oscap_list_new();
 	rule->sub.rule.fixtexts = oscap_list_new();
+
 	return rule;
 }
 
@@ -571,13 +574,6 @@ struct xccdf_check_content_ref *xccdf_check_content_ref_clone(const struct xccdf
 	return new_ref;
 }
 
-
-static const struct oscap_string_map XCCDF_BOOLOP_MAP[] = {
-	{XCCDF_OPERATOR_AND, "and"}, {XCCDF_OPERATOR_AND, "AND"},
-	{XCCDF_OPERATOR_OR, "or"}, {XCCDF_OPERATOR_OR, "OR"},
-	{0, NULL}
-};
-
 struct xccdf_check *xccdf_check_parse(xmlTextReaderPtr reader)
 {
 	xccdf_element_t el = xccdf_element_get(reader);
