@@ -177,6 +177,7 @@ oscap_xml_save_filename(const char *filename, xmlDocPtr doc)
 				S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH);
 		if (fd < 0) {
 			oscap_seterr(OSCAP_EFAMILY_GLIBC, "%s '%s'", strerror(errno), filename);
+			xmlFreeDoc(doc);
 			return -1;
 		}
 
@@ -185,6 +186,7 @@ oscap_xml_save_filename(const char *filename, xmlDocPtr doc)
 			close(fd);
 			oscap_setxmlerr(xmlGetLastError());
 			oscap_dlprintf(DBG_W, "xmlOutputBufferCreateFile() failed.\n");
+			xmlFreeDoc(doc);
 			return -1;
 		}
 
@@ -200,3 +202,7 @@ oscap_xml_save_filename(const char *filename, xmlDocPtr doc)
 	return (xmlCode >= 1) ? 1 : -1;
 }
 
+void libxml_error_handler(void *user, const char *message, xmlParserSeverities severity, xmlTextReaderLocatorPtr locator)
+{
+	oscap_setxmlerr(xmlGetLastError());
+}
