@@ -30,6 +30,7 @@
 #include <stdarg.h>
 
 #include "list.h"
+static inline bool _oscap_iterator_has_more_internal(const struct oscap_iterator *it);
 
 struct oscap_list *oscap_list_new(void)
 {
@@ -161,7 +162,7 @@ void* oscap_list_find(struct oscap_list *list, void *what, oscap_cmp_func compar
 
 	struct oscap_iterator *it = oscap_iterator_new(list);
 
-	while (oscap_iterator_has_more(it)) {
+	while (_oscap_iterator_has_more_internal(it)) {
 		void *item = oscap_iterator_next(it);
 		if (compare(item, what)) {
 			oscap_iterator_free(it);
@@ -204,7 +205,7 @@ static inline void oscap_iterator_find_nearest(struct oscap_iterator *it)
 
 	do {
 		it->cur = (it->cur ? it->cur->next : it->list->first);
-	} while (it->cur && !it->filter(it->cur->data, it->user_data) && oscap_iterator_has_more(it));
+	} while (it->cur && !it->filter(it->cur->data, it->user_data) && _oscap_iterator_has_more_internal(it));
 }
 
 void *oscap_iterator_new(struct oscap_list *list)
@@ -221,7 +222,6 @@ void *oscap_iterator_new_filter(struct oscap_list *list, oscap_filter_func filte
 	struct oscap_iterator *it = oscap_iterator_new(list);
 	it->filter = filter;
 	it->user_data = user_data;
-	oscap_iterator_find_nearest(it);
 	return it;
 }
 
@@ -283,10 +283,24 @@ void *oscap_iterator_next(struct oscap_iterator *it)
 	return it->cur->data;
 }
 
+static inline bool _oscap_iterator_has_more_internal(const struct oscap_iterator *it)
+{
+	return (!it->cur && it->list->first) || (it->cur && it->cur->next);
+}
+
 bool oscap_iterator_has_more(struct oscap_iterator *it)
 {
-	if (!it) return false;
-	return (!it->cur && it->list->first) || (it->cur && it->cur->next);
+	if (!it || !it->list || !it->list->first)
+		return false;
+	if (it->cur == NULL) {
+		if (it->filter(it->list->first->data, it->user_data))
+			return true;
+		else
+			it->cur = it->list->first;
+	}
+	while (it->cur->next && !it->filter(it->cur->next->data, it->user_data))
+		it->cur = it->cur->next;
+	return it->cur->next != NULL;
 }
 
 void oscap_iterator_reset(struct oscap_iterator * it)
@@ -329,7 +343,7 @@ OSCAP_ITERATOR_REMOVE(oscap_stringlist, oscap_stringlist_free)
     /*OSCAP_ITERATOR_RESET(oscap_string)*/
 
 
-#define OSCAP_DEFAULT_HSIZE 256
+#define OSCAP_DEFAULT_HSIZE 389
 static inline unsigned int oscap_htable_hash(const char *str, size_t htable_size)
 {
 	unsigned h = 0;
@@ -497,6 +511,113 @@ void oscap_htable_free(struct oscap_htable *htable, oscap_destruct_func destruct
 	}
 }
 
+void oscap_htable_free0(struct oscap_htable *htable)
+{
+	oscap_htable_free(htable, NULL);
+}
+
+struct oscap_htable_iterator {
+	struct oscap_htable *htable;	// Table we iterate through
+	struct oscap_htable_item *cur;	// The current item
+	size_t hpos;			// Line on which we are now
+};
+
+struct oscap_htable_iterator *
+oscap_htable_iterator_new(struct oscap_htable *htable)
+{
+	struct oscap_htable_iterator *hit = oscap_calloc(1, sizeof(struct oscap_htable_iterator));
+	hit->htable = htable;
+	hit->cur = NULL;
+	hit->hpos = 0;
+	return hit;
+}
+
+bool
+oscap_htable_iterator_has_more(struct oscap_htable_iterator *hit)
+{
+	__attribute__nonnull__(hit);
+	size_t i = hit->hpos;
+	if (hit->cur != NULL) {
+		if (hit->cur->next != NULL)
+			return true;
+		if (i + 1 >= hit->htable->hsize)
+			return false;
+		i++;
+	}
+	for (; i < hit->htable->hsize; i++) {
+		if (hit->htable->table[i] == NULL)
+			continue;
+		if (i != hit->hpos)
+			hit->hpos = i - 1;
+		return true;
+	}
+	hit->hpos = i;
+	return false;
+}
+
+const struct oscap_htable_item *
+oscap_htable_iterator_next(struct oscap_htable_iterator *hit)
+{
+	__attribute__nonnull__(hit);
+	if (hit->cur != NULL) {
+		if (hit->cur->next != NULL) {
+			hit->cur = hit->cur->next;
+			return hit->cur;
+		}
+		if (hit->hpos + 1 >= hit->htable->hsize) {
+			assert(false);
+			return NULL;
+		}
+		hit->hpos++;
+	}
+	for (; hit->hpos < hit->htable->hsize; hit->hpos++) {
+		if (hit->htable->table[hit->hpos] == NULL)
+			continue;
+		hit->cur = hit->htable->table[hit->hpos];
+		return hit->cur;
+	}
+	assert(false); // no more item found
+	return NULL;
+}
+
+const char *
+oscap_htable_iterator_next_key(struct oscap_htable_iterator *hit)
+{
+	const struct oscap_htable_item *item = oscap_htable_iterator_next(hit);
+	return (item == NULL) ? NULL : item->key;
+}
+
+void *
+oscap_htable_iterator_next_value(struct oscap_htable_iterator *hit)
+{
+	const struct oscap_htable_item *item = oscap_htable_iterator_next(hit);
+	return (item == NULL) ? NULL : item->value;
+}
+
+void oscap_htable_iterator_next_kv(struct oscap_htable_iterator *hit, const char **key, void **value)
+{
+	const struct oscap_htable_item *item = oscap_htable_iterator_next(hit);
+	if (item == NULL)
+		return;
+
+	*key = item->key;
+	*value = item->value;
+}
+
+void
+oscap_htable_iterator_reset(struct oscap_htable_iterator *hit)
+{
+	__attribute__nonnull__(hit);
+	hit->cur = NULL;
+	hit->hpos = 0;
+}
+
+void
+oscap_htable_iterator_free(struct oscap_htable_iterator *hit)
+{
+	oscap_free(hit);
+}
+
 void oscap_print_depth(int depth)
 {
 	while (depth--)
