@@ -36,6 +36,7 @@
 #define NS_DUBLINCORE BAD_CAST "http://purl.org/dc/elements/1.1/"
 
 OSCAP_ACCESSOR_SIMPLE(bool,oscap_reference,is_dublincore)
+OSCAP_ACCESSOR_STRING(oscap_reference,href)
 OSCAP_ACCESSOR_STRING(oscap_reference,title)
 OSCAP_ACCESSOR_STRING(oscap_reference,creator)
 OSCAP_ACCESSOR_STRING(oscap_reference,subject)
@@ -77,24 +78,33 @@ void oscap_reference_free(struct oscap_reference *ref)
         oscap_free(ref->relation);
         oscap_free(ref->coverage);
         oscap_free(ref->rights);
+        oscap_free(ref->href);
         oscap_free(ref);
     }
 }
 
-#define DC_ITEM_TO_DOM(ITEM) do { xmlNewTextChild(ref_node, ns_dc, BAD_CAST #ITEM, BAD_CAST ref->ITEM); } while(0)
+#define DC_ITEM_TO_DOM(ITEM) do { \
+    if (ref->ITEM != NULL) \
+        xmlNewTextChild(ref_node, ns_dc, BAD_CAST #ITEM, BAD_CAST ref->ITEM); \
+    } while(0)
 
 xmlNode *oscap_reference_to_dom(struct oscap_reference *ref, xmlNode *parent, xmlDoc *doc, const char *elname)
 {
     if (!ref) return NULL;
     xmlNode *ref_node = xmlNewChild(parent, NULL, BAD_CAST elname, NULL);
-    
+
+    if (ref->href != NULL)
+        xmlNewProp(ref_node, BAD_CAST "href", BAD_CAST ref->href);
+
     if (!ref->is_dublincore) {
         xmlNodeAddContent(ref_node, BAD_CAST ref->title);
-        xmlNewProp(ref_node, BAD_CAST "href", BAD_CAST ref->identifier);
         return ref_node;
     }
     
     xmlNs *ns_dc = xmlSearchNsByHref(doc, parent, NS_DUBLINCORE);
+    if (ns_dc == NULL) // the namespace hasn't been defined in ancestor elements
+        ns_dc = xmlNewNs(ref_node, NS_DUBLINCORE, BAD_CAST "dc");
+
     DC_ITEM_TO_DOM(title);
     DC_ITEM_TO_DOM(creator);
     DC_ITEM_TO_DOM(subject);
@@ -114,7 +124,10 @@ xmlNode *oscap_reference_to_dom(struct oscap_reference *ref, xmlNode *parent, xm
     return ref_node;
 }
 
-#define DC_DOM_SCAN(ITEM) do { if (oscap_streq((const char*)cur->name, #ITEM)) ref->ITEM = (char*) xmlNodeGetContent(ref_node); } while(0)
+#define DC_DOM_SCAN(ITEM) do { \
+    if (oscap_streq((const char*)cur->name, #ITEM)) \
+        ref->ITEM = (char*) xmlNodeGetContent(cur); \
+    } while(0)
 
 struct oscap_reference *oscap_reference_new_parse(xmlTextReaderPtr reader)
 {
@@ -126,15 +139,18 @@ struct oscap_reference *oscap_reference_new_parse(xmlTextReaderPtr reader)
 
     xmlNode* ref_node = xmlTextReaderExpand(reader);
 
+    ref->href = (char*) xmlGetProp(ref_node, BAD_CAST "href");
+
     for (xmlNode* cur = ref_node->children; cur != NULL; cur = cur->next)
 		if (cur->type == XML_ELEMENT_NODE) { ref->is_dublincore = true; break; }
 
     if (ref->is_dublincore) {
         for (xmlNode* cur = ref_node->children; cur != NULL; cur = cur->next) {
-            if (cur->type == XML_ELEMENT_NODE
+            if (cur->type != XML_ELEMENT_NODE
 				|| cur->ns == NULL
 				|| !oscap_streq((const char* ) cur->ns->href, (const char *) NS_DUBLINCORE))
 					continue;
+
             DC_DOM_SCAN(title);
             DC_DOM_SCAN(creator);
             DC_DOM_SCAN(subject);
@@ -153,7 +169,6 @@ struct oscap_reference *oscap_reference_new_parse(xmlTextReaderPtr reader)
         }
     }
     else {
-        ref->identifier = (char*) xmlGetProp(ref_node, BAD_CAST "href");
         ref->title = (char*) xmlNodeGetContent(ref_node);
     }
 
@@ -187,6 +202,7 @@ struct oscap_reference *oscap_reference_clone(const struct oscap_reference *ref)
     DC_ITEM_CLONE(relation);
     DC_ITEM_CLONE(coverage);
     DC_ITEM_CLONE(rights);
+    DC_ITEM_CLONE(href);
 
     return new_ref;
 }
