@@ -40,8 +40,8 @@
 #include "list.h"
 
 const char * const OSCAP_LANG_ENGLISH    = "en";
-const char * const OSCAP_LANG_ENGLISH_US = "en_US";
-const char * const OSCAP_LANG_DEFAULT    = "en_US";
+const char * const OSCAP_LANG_ENGLISH_US = "en-US";
+const char * const OSCAP_LANG_DEFAULT    = "en-US";
 
 const struct oscap_text_traits OSCAP_TEXT_TRAITS_PLAIN = { .html = false };
 const struct oscap_text_traits OSCAP_TEXT_TRAITS_HTML  = { .html = true };
@@ -132,9 +132,15 @@ xmlNode *oscap_text_to_dom(struct oscap_text *text, xmlNode *parent, const char
 
 	xmlNode *text_node = NULL;
 
-	if (text->traits.html || text->traits.can_substitute)
+	if (text->traits.html || text->traits.can_substitute) {
 		text_node = oscap_xmlstr_to_dom(parent, elname, text->text);
-	else text_node = xmlNewTextChild(parent, NULL, BAD_CAST elname, BAD_CAST text->text);
+		// make sure we use parent's namespace
+		xmlSetNs(text_node, parent->ns);
+	}
+	else {
+		// NULL as ns here means that namespace is inherited from parent
+		text_node = xmlNewTextChild(parent, NULL, BAD_CAST elname, BAD_CAST text->text);
+	}
 
 	if (text_node == NULL) return NULL;
 
@@ -199,25 +205,33 @@ bool oscap_textlist_export(struct oscap_text_iterator *texts, xmlTextWriter *wri
 	return true;
 }
 
-char* oscap_textlist_get_preferred_plaintext(struct oscap_text_iterator* texts, const char* preferred_lang)
+char *oscap_textlist_get_preferred_plaintext(struct oscap_text_iterator *texts, const char *preferred_lang)
 {
 	if (preferred_lang == NULL)
 		preferred_lang = OSCAP_LANG_DEFAULT;
 
 	oscap_text_iterator_reset(texts);
 
-	while (oscap_text_iterator_has_more(texts))
-	{
-		struct oscap_text* text = oscap_text_iterator_next(texts);
-		if (strcmp(oscap_text_get_lang(text), preferred_lang) == 0)
+	while (oscap_text_iterator_has_more(texts)) {
+		struct oscap_text *text = oscap_text_iterator_next(texts);
+		const char *lang = oscap_text_get_lang(text);
+		if (lang && strcmp(lang, preferred_lang) == 0)
 			return oscap_text_get_plaintext(text);
 	}
 
-	// not found in preferred language, fallback to any language
+	// not found as exact match in preferred language, try to find implicit match
 	oscap_text_iterator_reset(texts);
-	while (oscap_text_iterator_has_more(texts))
-	{
-		struct oscap_text* text = oscap_text_iterator_next(texts);
+	while (oscap_text_iterator_has_more(texts)) {
+		struct oscap_text *text = oscap_text_iterator_next(texts);
+		const char *lang = oscap_text_get_lang(text);
+		if (lang == NULL)
+			return oscap_text_get_plaintext(text);
+	}
+
+	// fallback to any language
+	oscap_text_iterator_reset(texts);
+	while (oscap_text_iterator_has_more(texts)) {
+		struct oscap_text *text = oscap_text_iterator_next(texts);
 		return oscap_text_get_plaintext(text);
 	}
 
