@@ -1,10 +1,13 @@
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 #include "oval_agent_api.h"
 #include "oval_results.h"
 #include "oscap.h"
-#include "error.h"
 
 int main(int argc, char *argv[]) {
 	struct oval_directives_model *model;
