@@ -4,9 +4,6 @@ set -e -o pipefail
 
 . $srcdir/../../../test_common.sh
 
-assert_exists() { [ $($XPATH $result 'count('"$2"')') == "$1" ]; }
-export -f assert_exists
-
 test_init test_api_xccdf_unittests.log
 #
 # API C Tests
@@ -28,6 +25,7 @@ test_run "check/@multi-check import/export" $srcdir/test_xccdf_check_multi_check
 test_run "check/@multi-check simple" $srcdir/test_xccdf_check_multi_check2.sh
 test_run "check/@multi-check that has zero definitions" $srcdir/test_xccdf_check_multi_check_zero_definitions.sh
 test_run "xccdf:check-content-ref without @name" $srcdir/test_xccdf_check_content_ref_without_name_attr.sh
+test_run "without xccdf:check-content-refs" $srcdir/test_xccdf_check_without_content_refs.sh
 test_run "xccdf:refine-rule/@weight shall not be exported" $srcdir/test_xccdf_refine_rule.sh
 test_run "xccdf:fix/@distruption|@complexity shall not be exported" $srcdir/test_xccdf_fix_attr_export.sh
 test_run "xccdf:complex-check/@operator=AND -- notchecked" $srcdir/test_xccdf_complex_check_and_notchecked.sh
@@ -48,6 +46,8 @@ test_run "Multiple xccdf:TestResult elements" $srcdir/test_xccdf_multiple_testre
 test_run "default selector for xccdf value" $srcdir/test_default_selector.sh
 test_run "inherit selector for xccdf value" $srcdir/test_inherit_selector.sh
 
+test_run "libxml errors handled correctly" $srcdir/test_unfinished.sh
+
 #
 # Tests for 'oscap xccdf eval --remediate' and substitution
 #
@@ -80,5 +80,6 @@ test_run "generate report: missing xsl shall not segfault" $srcdir/test_report_w
 test_run "generate report: avoid warnings from libxml" $srcdir/test_report_without_oval_poses_no_errors.sh
 test_run "generate fix: just as the anaconda does" $srcdir/test_report_anaconda_fixes.sh
 test_run "generate fix: just as the anaconda does + DataStream" $srcdir/test_report_anaconda_fixes_ds.sh
+test_run "generate fix: ensure filtering drop fixes" $srcdir/test_fix_filtering.sh
 
 test_exit
