@@ -31,7 +31,7 @@ function test_probes_fileextendedattribute {
 
     touch /tmp/xattr_noattr
 
-    ../../../utils/.libs/oscap oval eval --results $RESFILE $DEFFILE
+    $OSCAP oval eval --results $RESFILE $DEFFILE
 
     if [ -f $RESFILE ]; then
 	verify_results "def" $DF $RF 1 && verify_results "tst" $DF $RF 3
