@@ -29,7 +29,7 @@ function test_probes_filehash58 {
     [ -f $RF ] && rm -f $RF
 
     bash ${srcdir}/test_probes_filehash58.xml.sh > $DF
-    ../../../utils/.libs/oscap oval eval --results $RF $DF
+    $OSCAP oval eval --results $RF $DF
     
     if [ -f $RF ]; then
 	verify_results "def" $DF $RF 13 && verify_results "tst" $DF $RF 120
@@ -38,6 +38,8 @@ function test_probes_filehash58 {
 	ret_val=1
     fi
 
+    [ $ret_val -eq 0 ] && rm -f /tmp/test_probes_filehash58.tmp
+
     return $ret_val
 }
 
