@@ -17,6 +17,7 @@
 # Test Cases.
 
 function test_probes_interface {
+    require 'ipcalc' || return 255
 
     local ret_val=0;
     local DF="test_probes_interface.xml"
@@ -33,7 +34,7 @@ function test_probes_interface {
 	> $DF
     LINES=$?
 
-    ../../../utils/.libs/oscap oval eval --results $RF $DF
+    $OSCAP oval eval --results $RF $DF
     
     if [ -f $RF ]; then
 	verify_results "def" $DF $RF 1 && verify_results "tst" $DF $RF $LINES
