@@ -30,7 +30,7 @@ function test_probes_process {
 
     bash ${srcdir}/test_probes_process.xml.sh > $DF
     LINES=$?
-    ../../../utils/.libs/oscap oval eval --results $RF $DF
+    $OSCAP oval eval --results $RF $DF
     
     if [ -f $RF ]; then
 	verify_results "def" $DF $RF 1 && verify_results "tst" $DF $RF $LINES
