@@ -136,3 +136,12 @@ function verify_results {
 
     return $([ $ret_val -eq 0 ])
 }
+
+assert_exists() {
+        real_cnt="$($XPATH $result 'count('"$2"')')"
+        if [ "$real_cnt" != "$1" ]; then
+                echo "Failed: expected count: $1, real count: $real_cnt, xpath: '$2'"
+                return 1
+        fi
+}
+export -f assert_exists
