@@ -254,7 +254,7 @@ static int app_info(const struct oscap_action *action)
 				char * temp_dir = NULL;
 				char * xccdf_file = NULL;
 
-		                temp_dir = oscap_acquire_temp_dir();
+		                temp_dir = oscap_acquire_temp_dir_bundled();
 		                if (temp_dir == NULL) {
 					ds_sds_index_free(sds);
 					oscap_string_iterator_free(checklist_it);
@@ -270,10 +270,11 @@ static int app_info(const struct oscap_action *action)
 				snprintf(xccdf_file, PATH_MAX, "%s/%s", temp_dir, "xccdf.xml");
 				struct xccdf_benchmark* bench = NULL;
 		                bench = xccdf_benchmark_import(xccdf_file);
+				free(xccdf_file);
 				if(!bench) {
 					ds_sds_index_free(sds);
 					oscap_string_iterator_free(checklist_it);
-					oscap_acquire_cleanup_dir(&temp_dir);
+					oscap_acquire_cleanup_dir_bundled(&temp_dir);
 					ds_stream_index_iterator_free(sds_it);
 					goto cleanup;
 				}
@@ -316,14 +317,13 @@ static int app_info(const struct oscap_action *action)
 				// already freed by policy!
 				//xccdf_benchmark_free(bench);
 
-				oscap_acquire_cleanup_dir(&temp_dir);
+				oscap_acquire_cleanup_dir_bundled(&temp_dir);
 				if (oscap_err()) {
 					/* This might have set error, when some of the removals failed.
 					   No need to abort this operation, we can safely procceed. */
 					fprintf(stderr, "%s %s\n", OSCAP_ERR_MSG, oscap_err_desc());
 					oscap_clearerr();
 				}
-				free(xccdf_file);
 			}
 			oscap_string_iterator_free(checklist_it);
 
@@ -376,6 +376,23 @@ static int app_info(const struct oscap_action *action)
 		rds_index_free(rds);
 	}
 	break;
+	case OSCAP_DOCUMENT_XCCDF_TAILORING:
+		printf("Document type: XCCDF Tailoring\n");
+
+		// XCCDF Tailoring is not trivial to parse and interpret without
+		// knowing which content file it is supposed to be used with.
+		//
+		// Since we don't have this info when `oscap info` is called, we
+		// can't list profiles the tailoring file adds.
+	break;
+	case OSCAP_DOCUMENT_CVE_FEED:
+		printf("Document type: CVE Feed\n");
+		// TODO: Provide more info about CVE feeds
+	break;
+	case OSCAP_DOCUMENT_SCE_RESULT:
+		printf("Document type: SCE Result File\n");
+		// Currently, we do not have any SCE result file parsing capabilities.
+	break;
 	default:
 		printf("Document type not handled yet\n");
 		break;
