@@ -276,19 +276,19 @@ int app_collect_oval(const struct oscap_action *action)
 			fprintf(stderr, "Object ID(%s) does not exist in '%s'.\n", action->id, action->f_oval);
 			goto cleanup;
 		}
-		fprintf(stderr, "Collected: \"%s\" : ", oval_object_get_id(object));
+		printf("Collected: \"%s\" : ", oval_object_get_id(object));
 		oval_probe_query_object(pb_sess, object, 0, &syschar);
 		sc_flg = oval_syschar_get_flag(syschar);
-		fprintf(stderr, "%s\n", oval_syschar_collection_flag_get_text(sc_flg));
+		printf("%s\n", oval_syschar_collection_flag_get_text(sc_flg));
 	}
 	else {
 	        struct oval_object_iterator *objects = oval_definition_model_get_objects(def_model);
 		while (oval_object_iterator_has_more(objects)) {
 			object = oval_object_iterator_next(objects);
-			fprintf(stderr, "Collected: \"%s\" : ", oval_object_get_id(object));
+			printf("Collected: \"%s\" : ", oval_object_get_id(object));
 			oval_probe_query_object(pb_sess, object, 0, &syschar);
 			sc_flg = oval_syschar_get_flag(syschar);
-			fprintf(stderr, "%s\n", oval_syschar_collection_flag_get_text(sc_flg));
+			printf("%s\n", oval_syschar_collection_flag_get_text(sc_flg));
 		}
 		oval_object_iterator_free(objects);
 	}
@@ -368,7 +368,7 @@ int app_evaluate_oval(const struct oscap_action *action)
 	oscap_document_type_t doc_type = 0;
 	if (oscap_determine_document_type(action->f_oval, &doc_type) == 0 && doc_type == OSCAP_DOCUMENT_SDS)
 	{
-		temp_dir = oscap_acquire_temp_dir();
+		temp_dir = oscap_acquire_temp_dir_bundled();
 		if (temp_dir == NULL)
 			goto cleanup;
 
@@ -469,8 +469,7 @@ int app_evaluate_oval(const struct oscap_action *action)
 
 	/* clean up */
 cleanup:
-	if(oscap_err())
-		fprintf(stderr, "%s %s\n", OSCAP_ERR_MSG, oscap_err_desc());
+	oscap_print_error();
 
 	if (sess) oval_agent_destroy_session(sess);
 	if (def_model) oval_definition_model_free(def_model);
