@@ -143,10 +143,8 @@ struct oscap_action {
 	int progress;
 	int oval_results;
 	int remediate;
-#ifdef ENABLE_SCE
 	char *sce_template;
-	int sce_results;
-#endif
+	int check_engine_results;
 	int export_variables;
         int list_dynamic;
 	char *probe_root;
@@ -162,8 +160,8 @@ int oscap_module_call(struct oscap_action *action);
 
 void oscap_print_error(void);
 
-char *oscap_acquire_temp_dir(void);
-void oscap_acquire_cleanup_dir(char **dir_path);
+char *oscap_acquire_temp_dir_bundled(void);
+void oscap_acquire_cleanup_dir_bundled(char **dir_path);
 
 extern struct oscap_module OSCAP_ROOT_MODULE;
 extern struct oscap_module OSCAP_DS_MODULE;
